********************************************************************************
* MASTER do-file                                                               *
*                                                                              *
* Syntax for analyses shown in:                                                *
* Schindler/Bittmann (2025): Education, Educational Upgrading and Labor Market *
* Outcomes: Descriptive Evidence by Social Background and Gender.              *
* LIfBi Working Paper No. 120. Leibniz Institute for Educational Trajectories. *
* https://doi.org/10.5157/LIfBi:WP120:1.0                                      *
*      							                                               *
* Steffen Schindler, 15/06/2025                                                *
********************************************************************************

*** Globals ********************************************************************

* folders with data source (data) and dofiles (dofile)  and to store new data files (savedta) and log files (savelog)
global data   	[specify path to folder where you stored the original NEPS datasets]
global dofile	[specify path to folder where you stored the do-files]
global savedta	[specify path to folder where you want to save new datasets created by the syntax]
global savelog	[specify path to folder where you want to save log files]

* version of NEPS-SC6 data
global SUF		"14-0-0"  // specify data version (this syntax has been created based on version 14-0-0)	 	  

*** Download ado files *********************************************************

* NEPS tools
net install nepstools, from(http://nocrypt.neps-data.de/stata) replace

*** Store relevant NEPS datasets with NEPSmiss *********************************
clear 
do "${dofile}\nepsmiss.do"

*** Recode and store basic information in wide format **************************

* Participation in waves
clear 
do "${dofile}\wavepart.do"

* Recode of time-invariant information (for imputation]
clear
do "${dofile}\basicinfo.do"

*** Expand spell data to monthly episodes **************************************
clear
do "${dofile}\month_episodes.do"

*** Identify date of first significant employment *****************************
clear
do "${dofile}\date_employ1.do"

*** Recode of information on education  ****************************************

* School-leaving degrees: basic recodes
clear
do "${dofile}\school_basics.do"

* School-leaving degrees: plausibility checks and data cleaning
clear
do "${dofile}\school_plausi.do"

* School-leaving degrees: recodes of key variables
clear
do "${dofile}\school_recode.do"

* Vocational degrees: basic recodes
clear
do "${dofile}\voctrain_basics.do"

* Vocational degrees: plausibility checks and data cleaning
clear
do "${dofile}\voctrain_plausi.do"

* Vocational degrees: recodes of key variables
clear
do "${dofile}\voctrain_recode.do"

* Merge information on school-leaving and vocational degrees
clear
do "${dofile}\educ_merge.do"

* Transfer education data into information-by-age format (wide format)
clear
do "${dofile}\educ_prep.do"

*** Recode of labor market information *****************************************

* Income: plausibility checks and data cleaning
clear
do "${dofile}\income_plausi.do"

* Income: recodes and transfer into information-by-age format (wide format) 
clear
do "${dofile}\income_prep.do"

* Occupation: recodes and transfer into information-by-age format (wide format)
clear
do "${dofile}\occupation_prep.do"

*** Prepare data for imputation ************************************************

* Merge data for imputation
clear
do "${dofile}\merge_imp.do"

* Prepare data for imputation (earnings age 40)
clear 
do "${dofile}\prep_imp40.do"

*** Impute data ****************************************************************

* conduct imputation (incl. python script)
clear
do "${dofile}\imputation.do"

*** Recode data after imputation ***********************************************

* recode central variables for analyses of earnings at age 40
clear
do "${dofile}\recode_imp40.do"

* Prepare variables for analyses
clear
do "${dofile}\prep_analyses.do"

*** Conduct analyses ***********************************************************

do "${dofile}\analyses.do"
























