********************************************************************************
* Recode of basic time-invariant information in wide format            		   *
*      							                                               *    
* Steffen Schindler, 15/06/2025                               				   *
********************************************************************************

clear
set more off
cap log close

version 16.1

use "${savedta}\SC6_Basics_D_${SUF}.dta"


*** recode variables ***********************************************************

*** gender
recode t700001 (1=0 "male") (2=1 "female"), into(gender)
lab var gender "gender"
ta t700001 gender, m

*** date of birth
gen birthdate = ym(t70000y,t70000m)
format birthdate %tm
lab var birthdate "birth date in months since Jan 1960"

*** year of birth
ren t70000y birthyear

*** parents' education

* father's CASMIN
lab copy en1957ext2 casmin
ren t731351_g2 casmin_f
lab val casmin_f casmin
lab var casmin_f "CASMIN father"

* mother's CASMIN
ren t731301_g2 casmin_m
lab val casmin_m casmin
lab var casmin_m "CASMIN mother"

* parents' highest CASMIN
egen casmin_p=rowmax(casmin_f casmin_m) 
lab val casmin_p casmin
lab var casmin_p "CASMIN parents (highest)"

* father's years of education
ren t731351_g3 educyears_f 
replace educyears_f=6 if educyears_f==.y // set to 6 years if no school-leaving degree
lab var educyears_f "years of education father"

* mother's years of education
ren t731301_g3 educyears_m 
replace educyears_m=6 if educyears_m==.y // set to 6 years if no school-leaving degree
lab var educyears_m "years of education mother"

* parents' years of education (maximum)
egen educyears_p=rowmax(educyears_f educyears_m)  
lab val educyears_p enmiss
lab var educyears_p "years of education parents (maximmum)"

*** parents' social class/status/prestige

* father's EGP class
lab copy en1917 egp
ren t731453_g8 egp_f
lab val egp_f egp
lab var egp_f "EGP class father"
recode egp_f (1 2=1 "salariat") (3 5 6 7 8=2 "intermediate") (4 9 10 11=3 "working") (.l=.l "not determinable"), into(egp3_f)
lab var egp3_f "EGP class father (3 categories)"

* mother's EGP class
ren t731403_g8 egp_m
lab val egp_m egp
lab var egp_m "EGP class mother"
recode egp_m (1 2=1 "salariat") (3 5 6 7 8=2 "intermediate") (4 9 10 11=3 "working") (.l=.l "not determinable"), into(egp3_m)
lab var egp3_m "EGP class mother (3 categories)"

* parents' highest EGP class
egen egp_p=rowmin(egp_f egp_m)
replace egp_p=.l if egp_p==.
lab val egp_p egp
lab var egp_p "EGP class parents (highest)
egen egp3_p=rowmin(egp3_f egp3_m)
replace egp3_p=.l if egp3_p==.
lab val egp3_p egp3_f
lab var egp3_p "EGP class parents (highest, 3 cat.)

* father's ISEI (based on ISCO-08)
ren t731453_g14 isei_f
lab var isei_f "ISEI (08) father"

* mother's ISEI (based on ISCO-08)
ren t731403_g14 isei_m
lab var isei_m "ISEI (08) mother"

* parents' highest ISEI (based on ISCO-08)
egen isei_p=rowmax(isei_f isei_m)
lab val isei_p enmiss
lab var isei_p "ISEI (08) parents (highest)"

* father's SIOPS (based on ISCO-08)
ren t731453_g16 siops_f
lab var siops_f "SIOPS (08) father"

* mother's SIOPS (based on ISCO-08)
ren t731403_g16 siops_m
lab var siops_m "SIOPS (08) mother"

* parents' highest SIOPS (based on ISCO-08)
egen siops_p=rowmax(siops_f siops_m)
lab val siops_p enmiss
lab var siops_p "SIOPS (08) parents (highest)"

*** migratory background
ren t400500_g1 migration_gen
lab var migration_gen "migration status (generation)"
recode migration_gen (0=0 "no migration history") (else=1 "migration background"), into(migration)
lab var migration "migratory background"
recode tx29005 (2=.a "immigrated, but age unknown") (1=.b "born in Germany") (.l=.c "migration status unknown"), into(migration_age) 
replace migration_age=tx29007 if tx29007<.
lab var migration_age "age of immigration (in years)"
ta migration_age tx29005, m


*** save data ******************************************************************
keep ID_t migration_gen casmin_m educyears_m egp_m egp3_m isei_m siops_m casmin_f educyears_f egp_f egp3_f isei_f siops_f gender birthdate birthyear casmin_p educyears_p egp_p egp3_p isei_p siops_p migration migration_age
order ID_t birthdate birthyear gender casmin_f casmin_m casmin_p educyears_f educyears_m educyears_p egp_f egp_m egp_p egp3_f egp3_m egp3_p isei_f isei_m isei_p siops_f siops_m siops_p migration migration_gen migration_age  

compress
save "${savedta}\basicinfo.dta", replace






















