


#Felix Bittmann, 2024
#felix.bittmann@lifbi.de


from os.path import join


age_min = 15
age_max = 40
outputpath = "C:/Users/ba9ga6/Local Folders/My Local Files/SC6/dofiles/new"



def writeline(focusvar, include, allvars, adjust=None):
	"""Generates the line to write in the do file for a specific variable"""
	omitvars = list(allvars - include)
	if focusvar in omitvars:
		omitvars.remove(focusvar)
	omitvars.sort()
	omit_string = ""
	for element in omitvars:
		omit_string = omit_string + " " + str(element)
	if adjust == None:
		newline = "(" + var["command"] + " omit(" + omit_string + ")) " + focusvar
	else:
		newline = "(" + var["command"] + adjust + " omit(" + omit_string + ")) " + focusvar
	return newline
	

### Autocorrelation vars ###
var_status_educ = {"name": "status_educ_", "command": "pmm, knn(4)", "auto": True, "factor": False, "adjust": False}
var_status_emp = {"name": "status_emp_", "command": "pmm, knn(4)", "auto": True, "factor": False, "adjust": False}
var_vocdegree = {"name": "vocdegree_", "command": "pmm, knn(4)", "auto": True, "factor": False, "adjust": False}
var_schooldegree = {"name": "schooldegree_", "command": "pmm, knn(4)", "auto": True, "factor": False, "adjust": False}


### Autocorrelation vars, dependent on employment ###
var_workh20 = {"name": "workh20_", "command": "pmm, knn(4)", "auto": True, "factor": False, "adjust": True}
var_isei = {"name": "isei_", "command": "pmm, knn(4)", "auto": True, "factor": False, "adjust": True}
var_eastwest = {"name": "eastwest_", "command": "pmm, knn(4)", "auto": True, "factor": False, "adjust": True}
var_pubserv = {"name": "pubserv_", "command": "pmm, knn(4)", "auto": True, "factor": False, "adjust": True}
var_empmonths = {"name": "empmonths_", "command": "pmm, knn(4)", "auto": True, "factor": False, "adjust": True}
var_selfemp = {"name": "selfemp_", "command": "pmm, knn(4)", "auto": True, "factor": False, "adjust": True}


### Time constant vars ###
var_egpp = {"name": "egp3_p", "command": "pmm, knn(4)", "auto": False, "factor": False, "adjust": False}
var_casminp = {"name": "casmin_p", "command": "ologit, ascont", "auto": False, "factor": True, "adjust": False}
var_iseip = {"name": "isei_p", "command": "pmm, knn(4)", "auto": False, "factor": False, "adjust": False}
var_vocdegree1 = {"name": "vocdegree_1", "command": "pmm, knn(4)", "auto": False, "factor": False, "adjust": False}
var_schooldegree1 = {"name": "schooldegree_1", "command": "pmm, knn(4)", "auto": False, "factor": False, "adjust": False}
var_gpa1 = {"name": "schooldegree_1_gpa", "command": "pmm, knn(4) conditional(if inrange(schooldegree_1, 1, 6))", "auto": False, "factor": False, "adjust": False}


### Conditional outcome vars ###
var_gross_earn = {"name": "gross_earn_40", "command": "pmm, knn(4) conditional(if status_emp_40 == 1)", "auto": False, "factor": False, "adjust": False}
var_bonus = {"name": "gross_bonus_40", "command": "pmm, knn(4) conditional(if status_emp_40 == 1)", "auto": False, "factor": False, "adjust": False}
var_neat_earn = {"name": "net_earn_40", "command": "pmm, knn(4) conditional(if status_emp_40 == 1)", "auto": False, "factor": False, "adjust": False}
var_workhours = {"name": "workhours_40", "command": "pmm, knn(4) conditional(if status_emp_40 == 1)", "auto": False, "factor": False, "adjust": False}


### Auxils ###
var_partfirst = {"name": "partfirst", "command": "pmm, knn(4)", "auto": False, "factor": False, "adjust": False}
var_partlast = {"name": "partlast", "command": "pmm, knn(4)", "auto": False, "factor": False, "adjust": False}
var_partnum = {"name": "partnum", "command": "pmm, knn(4)", "auto": False, "factor": False, "adjust": False}
var_birthyear = {"name": "birthyear", "command": "pmm, knn(4)", "auto": False, "factor": False, "adjust": False}
var_gender = {"name": "gender", "command": "pmm, knn(4)", "auto": False, "factor": False, "adjust": False}
var_migration = {"name": "migration_gen3", "command": "ologit,", "auto": False, "factor": True, "adjust": False}
var_gross_earn_aux1 = {"name": "gross_earn_auxlow", "command": "pmm, knn(4)", "auto": False, "factor": False, "adjust": False}
var_gross_bonus_aux1 = {"name": "gross_bonus_auxlow", "command": "pmm, knn(4)", "auto": False, "factor": False, "adjust": False}
var_net_earn_aux1 = {"name": "net_earn_auxlow", "command": "pmm, knn(4)", "auto": False, "factor": False, "adjust": False}
var_workhours_aux1 = {"name": "workhours_auxlow", "command": "pmm, knn(4)", "auto": False, "factor": False, "adjust": False}


### Puting all vars together, must be done manually ###
allvars = [var_status_educ, var_status_emp, var_vocdegree, var_schooldegree,
	var_workh20, var_isei, var_eastwest, var_pubserv, var_empmonths, var_selfemp,
	var_casminp, var_iseip, var_egpp, var_vocdegree1, var_schooldegree1, var_gpa1,
	var_gross_earn, var_bonus, var_neat_earn, var_workhours,
	var_partfirst, var_partlast, var_partnum, var_birthyear, var_gender, var_migration,
	var_gross_earn_aux1, var_gross_bonus_aux1, var_net_earn_aux1, var_workhours_aux1]


#Define saturated model with all possible variables
fullmodel = set()
for var in allvars:
	if var["auto"] == True:
		for age in range(age_min, age_max + 1):
			fullmodel.add(var["name"] + str(age))
	else:
		fullmodel.add(var["name"])
		
### Tuple in Liste umwandeln ###		
fullmodel_list = list(fullmodel)
fullmodel_list.sort()
#Required to register imputed variables
outputstring = ""
for element in fullmodel_list:
	outputstring = outputstring + " " + str(element)


#Prepare Dofile
filepath = join(outputpath, "dofile_imputation.do")
output = open(filepath, "w")
output.write("mi set flong" + "\n")
output.write("mi register imputed " + outputstring + "\n")
output.write("\n")
output.write("mi impute chained" + " ///" + "\n")



"""In this part we loop over all variables in the dataset and build a proper imputation regression
for each. Which variables are included in the model depend on their specific type"""
for var in allvars:
	if var["auto"] == True:				#Focusvar is time-varying (e.g. status_educ)
		for time in range(age_min, age_max + 1):	#For time-varying vars we need to account for all years in the dataset
			focusvar = var["name"] + str(time)
			include = set()
			### Autocorrelated values ###
			if time > 30:
				include.add(var["name"] + str(max(age_min, time - 10)))
				include.add(var["name"] + str(max(age_min, time - 5)))
				include.add(var["name"] + str(max(age_min, time - 3)))		#added by steffen
			else:
				include.add(var["name"] + str(max(age_min, time - 7)))
				include.add(var["name"] + str(max(age_min, time - 3)))
				include.add(var["name"] + str(max(age_min, time - 1)))		#added by steffen
			### Other variables ###
			for innervar in allvars:
				if var == innervar or "aux" in innervar["name"]:					#Cannot predict own value, skip also auxils for outcomes
					continue
				elif innervar["auto"] == True:		#Other variable is time-varying
					if time > 30:
						include.add(innervar["name"] + str(max(age_min, time - 10)))
						include.add(innervar["name"] + str(max(age_min, time - 1)))
						include.add(innervar["name"] + str(max(age_min, time - 0)))		#added by steffen
					else:
						include.add(innervar["name"] + str(max(age_min, time - 5)))
						include.add(innervar["name"] + str(max(age_min, time - 1)))
						include.add(innervar["name"] + str(max(age_min, time - 0)))		#added by steffen
				else:								#Time-constant other variable is taken as is
					include.add(innervar["name"])
			
			"""In this part we need to adjust for those variables that are conditional
			on other variables. They are only imputed if the individual is employed
			at time = t"""
			if var["adjust"] == False:	
				towrite = writeline(focusvar, include, fullmodel)
			else:
				conditional = " conditional(if status_emp_" + str(time) + " == 1)"
				towrite = writeline(focusvar, include, fullmodel, conditional)
			output.write(towrite + " /// " + "\n")
			output.write("/// " + "\n")
			print(focusvar)
	else:								#Focusvar is constant/unique (e.g. parental EGP)
		focusvar = var["name"]
		include = set()
		for innervar in allvars:
			if var == innervar:			#Var cannot predict itself
				continue
			if "aux" in innervar["name"] and not "status_emp_40" in var["command"]:
				continue						#Only include outcome auxils for these specific outcomes
			if innervar["auto"] == True:		#If other var is time-varying, taking it from age 20, 30, and 40
				include.add(innervar["name"] + str(20))
				include.add(innervar["name"] + str(30))
				include.add(innervar["name"] + str(40))
			else:
				include.add(innervar["name"])
		towrite = writeline(focusvar, include, fullmodel)
		output.write(towrite + " /// " + "\n")
		output.write("/// " + "\n")
		print(focusvar)
	
### Finalize imputation model ###		
output.write("/// " + "\n")
output.write("/// " + "\n")
output.write(", add(50) burnin(20) rseed(8344651) dots")	
output.close()		


print("")
print("###############################################################")
print("Done! The imputation model has been generated!")
print("Dofile created in", outputpath)









