********************************************************************************
* Prepare education history for imputation                                     *
*                                                                              *    
* Steffen Schindler, 15/06/2025                                                *
********************************************************************************

clear
set more off
cap log close

version 16.1

use ID_t month birthdate agem agey migration_age schooldegree_cum schooldegree_add schoolgpa vocdegree_cum vocdegree_add using "${savedta}\educ_merge", clear


*** RECODE EDUCATION VARIABLES *************************************************

*** recode school-leaving degree variables

* recode indicator if new school-leaving degree has been obtained into binary variable
replace schooldegree_add=.m if schooldegree_cum==.m & schooldegree_add!=1
replace schooldegree_add=0 if schooldegree_add==.
lab def schooldegree_add 0"no new degree obtained" 1"any new degree obtained" .m"case without any schooldegree information"
lab val schooldegree_add schooldegree_add

* generate variable indicating if most recent school-leaving degree has been obtained abroad
gen schooldegree_abroad=0
replace schooldegree_abroad=1 if inlist(schooldegree_cum,1,3,5,7,9,11,13,15,17,19,21,23,.a,.c,.d,.e,.f,.g,.h)
replace schooldegree_abroad=.m if schooldegree_cum==.m
lab var schooldegree_abroad "most recent school-leaving degree obtained abroad"
lab def schooldegree_abroad 0 "in Germany" 1 "abroad" .m "case without any schooldegree information"
lab val schooldegree_abroad schooldegree_abroad
ta schooldegree_cum schooldegree_abroad,m 

* generate variable to be used as predictor for imputation of schooldegree
lab def schooldegree_imp ///
0 "no degree or more" ///
1 "special needs or more" ///
2 "Haupt or more" ///
3 "qual.Haupt or more" ///
4 "Mittl.Reife of more" ///
5 "FH-Reife or more" ///
.m "case without any schooldegree information"
recode schooldegree_cum (0/2=0) (3/6=1) (7/10=2) (11/14=3) (15/18=4) (19/24=5) (.m=.m), into(schooldegree_imp)
lab var schooldegree_imp "imputation predictor for schooldegree"
lab val schooldegree_imp schooldegree_imp
ta schooldegree_cum schooldegree_imp,m 

* recode schooldegree_cum into new variable with missing values for uncertain degrees (schooldegree)
lab def schooldegree ///
0 "no degree" ///
1 "special needs" ///
2 "Haupt" ///
3 "qual.Haupt" ///
4 "Mittl.Reife" ///
5 "FH-Reife" ///
6 "Abitur" ///
.n "unclear degree" ///
.m "case without any schooldegree information"
recode schooldegree_cum (0=0) (3 4=1) (7 8=2) (11 12=3) (15 16=4) (19 20=5) (23 24=6) (.m=.m) (else=.n), into(schooldegree)
lab var schooldegree "highest school-leaving degree (time-variant)"
lab val schooldegree schooldegree
ta schooldegree_cum schooldegree,m

*** recode vocational degree variables

* recode indicator if new school-leaving degree has been obtained into binary variable
replace vocdegree_add=.m if vocdegree_cum==.m & vocdegree_add!=1
replace vocdegree_add=0 if vocdegree_add==.
lab def vocdegree_add 0"no new degree obtained" 1"any new degree obtained" .m"case without any vocdegree information"
lab val vocdegree_add vocdegree_add

* generate variable indicating if most recent vocational degree has been obtained abroad
gen vocdegree_abroad=0
replace vocdegree_abroad=1 if inlist(vocdegree_cum,1,3,5,7,9,11,13,15)
replace vocdegree_abroad=.m if vocdegree_cum==.m
lab var vocdegree_abroad "most recent vocational degree obtained abroad"
lab def vocdegree_abroad 0 "in Germany" 1 "abroad" .m "case without any vocdegree information"
lab val vocdegree_abroad vocdegree_abroad
ta vocdegree_cum vocdegree_abroad,m 

* generate variable to be used as predictor for imputation of vocdegree
lab def vocdegree_imp ///
0 "no voc.degree or more" ///
1 "VOC1 or more" ///
2 "VOC2 or more" ///
3 "HE1 or more" ///
.m "case without any vocdegree information"
recode vocdegree_cum (0/2=0) (3/6=1) (7/10=2) (11/16=3) (.m=.m), into(vocdegree_imp)
lab var vocdegree_imp "imputation predictor for vocdegree"
lab val vocdegree_imp vocdegree_imp
ta vocdegree_cum vocdegree_imp,m 

* recode vocdegree_cum into new variable with missing values for uncertain degrees (vocdegree)
lab def vocdegree ///
0 "no voc.degree" ///
1 "VOC1" ///
2 "VOC2" ///
3 "HE1" ///
4 "HE2" ///
.n "unclear degree" ///
.m "case without any vocdegree information"
recode vocdegree_cum (0=0) (3 4=1) (7 8=2) (11 12=3) (15 16=4) (1 2 5 6 9 10 13 14=.n) (.m=.m), into(vocdegree)
lab var vocdegree "highest vocational degree (time-variant)"
lab val vocdegree vocdegree
ta vocdegree_cum vocdegree,m

*** generate combined school and vocational degree variables

* define label
lab def educdegree ///
10 "no voc - no school" ///
11 "no voc - spec.needs" ///
12 "no voc - Haupt" ///
13 "no voc - qual.Haupt" ///
14 "no voc - MR" ///
15 "no voc - FHR" ///
16 "no voc - Abitur" ///
20 "VOC1 - no school" ///
21 "VOC1 - spec.needs" ///
22 "VOC1 - Haupt" ///
23 "VOC1 - qual.Haupt" ///
24 "VOC1 - MR" ///
25 "VOC1 - FHR" ///
26 "VOC1 - Abitur" ///
30 "VOC2 - no school" ///
31 "VOC2 - spec.needs" ///
32 "VOC2 - Haupt" ///
33 "VOC2 - qual.Haupt" ///
34 "VOC2 - MR" ///
35 "VOC2 - FHR" ///
36 "VOC2 - Abitur" ///
40 "HE1 - no school" ///
41 "HE1 - spec.needs" ///
42 "HE1 - Haupt" ///
43 "HE1 - qual.Haupt" ///
44 "HE1 - MR" ///
45 "HE1 - FHR" ///
46 "HE1 - Abitur" ///
50 "HE2 - no school" ///
51 "HE2 - spec.needs" ///
52 "HE2 - Haupt" ///
53 "HE2 - qual.Haupt" ///
54 "HE2 - MR" ///
55 "HE2 - FHR" ///
56 "HE2 - Abitur" ///
.a "no voc - school unknown" ///
.b "VOC1 - school unknown" ///
.c "VOC2 - school unknown" ///
.d "HE1 - school unknown" ///
.e "HE2 - school unknown" ///
.f "voc unknown - no school" ///
.g "voc unknown - spec.needs" ///
.h "voc unknown - Haupt" ///
.i "voc unknown - qual.Haupt" ///
.j "voc unknown - MR" ///
.k "voc unknown - FHR" ///
.l "voc unknown - Abitur" ///
.m "voc unknown - school unknown"

* recode
recode vocdegree (0=10) (1=20) (2=30) (3=40) (4=50) (.m .n=.m), into(educdegree)
forvalues i=0/6 { 
   replace educdegree=educdegree+`i' if schooldegree==`i' & educdegree<.	
}
replace educdegree=.a if educdegree==10 & inlist(schooldegree,.m,.n) 
replace educdegree=.b if educdegree==20 & inlist(schooldegree,.m,.n) 
replace educdegree=.c if educdegree==30 & inlist(schooldegree,.m,.n) 
replace educdegree=.d if educdegree==40 & inlist(schooldegree,.m,.n) 
replace educdegree=.e if educdegree==50 & inlist(schooldegree,.m,.n) 
replace educdegree=.f if educdegree==.m & schooldegree==0
replace educdegree=.g if educdegree==.m & schooldegree==1
replace educdegree=.h if educdegree==.m & schooldegree==2
replace educdegree=.i if educdegree==.m & schooldegree==3
replace educdegree=.j if educdegree==.m & schooldegree==4
replace educdegree=.k if educdegree==.m & schooldegree==5
replace educdegree=.l if educdegree==.m & schooldegree==6
replace educdegree=.m if educdegree==.m & schooldegree==7
lab var educdegree "highest combined school and vocational degree (time-variant)"
lab val educdegree educdegree
ta educdegree vocdegree,m
ta educdegree schooldegree,m

*** generate indicators of first/highest school/vocational degrees

* first school-leaving degree 
bys ID_t: egen temp1=min(month) if inrange(schooldegree,1,6) | schooldegree==.n
replace temp1=. if temp1!=month
replace temp1=schooldegree if temp1!=. // if any school leaving degree
replace temp1=99 if temp1==.n // when first degree is unknown
bys ID_t: egen schooldegree_1=max(temp1)
recode schooldegree_1 99=.n 
bys ID_t: egen temp2=max(schooldegree) if schooldegree_1==., missing
replace schooldegree_1=temp2 if schooldegree_1==. // if no school leaving degree or no schooldegree information
lab var schooldegree_1 "first school-leaving degree"
lab val schooldegree_1 schooldegree
drop temp2
ta schooldegree_1,m 

* age and month first school-leaving degree
gen temp_age=agem if temp1<.
bys ID_t: egen schooldegree_1_agem=max(temp_age)
replace schooldegree_1_agem=.a if schooldegree_1==0
replace schooldegree_1_agem=.m if schooldegree_1==.m
lab def schooldegree_miss .a "no degree" .m "case without any schooldegree information"
lab val schooldegree_1_agem schooldegree_miss
lab var schooldegree_1_agem "age in months first school-leaving degree"
gen schooldegree_1_agey=schooldegree_1_agem/12
lab var schooldegree_1_agey "age in years first school-leaving degree"
lab val schooldegree_1_agey schooldegree_miss
gen temp_month=month if temp1<.
bys ID_t: egen schooldegree_1_month=max(temp_month)
replace schooldegree_1_month=.a if schooldegree_1==0
replace schooldegree_1_month=.m if schooldegree_1==.m
format schooldegree_1_month %tm
lab val schooldegree_1_month schooldegree_miss
lab var schooldegree_1_month "month (since 01/1960) first school-leaving degree"
drop temp*

* GPA first school-leaving degree
gen temp=schoolgpa if month==schooldegree_1_month
replace temp=.z if temp==.
bys ID_t: egen schooldegree_1_gpa=min(temp), missing
replace schooldegree_1_gpa=.y if schooldegree_1==0
replace schooldegree_1_gpa=.a if schooldegree_1_gpa==.z
replace schooldegree_1_gpa=round(schooldegree_1_gpa,.1)
lab var schooldegree_1_gpa "GPA first school-leaving degree"
lab val schooldegree_1_gpa schoolgpa
drop temp

* highest school-leaving degree 
bys ID_t: egen schooldegree_h=max(schooldegree)
bys ID_t: egen temp1=max(schooldegree) if schooldegree_h==. | schooldegree_h==0, missing
replace schooldegree_h=temp1 if (schooldegree_h==. | schooldegree_h==0) & inlist(temp1,.m,.n) // cases without any information on school degrees
lab var schooldegree_h "highest school-leaving degree"
lab val schooldegree_h schooldegree
drop temp1
ta schooldegree_h,m 

* age and month highest school-leaving degree
bys ID_t: egen temp_age=min(agem) if schooldegree_h==schooldegree & !inlist(schooldegree_h,0,.m)
bys ID_t: egen schooldegree_h_agem=max(temp_age)
replace schooldegree_h_agem=.a if schooldegree_h==0
replace schooldegree_h_agem=.m if schooldegree_h==.m
lab val schooldegree_h_agem schooldegree_miss
lab var schooldegree_h_agem "age in months highest school-leaving degree"
gen schooldegree_h_agey=schooldegree_h_agem/12
lab var schooldegree_h_agey "age in years highest school-leaving degree"
lab val schooldegree_h_agey schooldegree_miss
bys ID_t: egen temp_month=min(month) if schooldegree_h==schooldegree & !inlist(schooldegree_h,0,.m)
bys ID_t: egen schooldegree_h_month=max(temp_month)
replace schooldegree_h_month=.a if schooldegree_h==0
replace schooldegree_h_month=.m if schooldegree_h==.m
format schooldegree_h_month %tm
lab val schooldegree_h_month schooldegree_miss
lab var schooldegree_h_month "month (since 01/1960) highest school-leaving degree"
drop temp*

* GPA highest school-leaving degree
gen temp=schoolgpa if month==schooldegree_h_month
replace temp=.z if temp==.
bys ID_t: egen schooldegree_h_gpa=min(temp), missing
replace schooldegree_h_gpa=.y if schooldegree_h==0
replace schooldegree_h_gpa=.a if schooldegree_h_gpa==.z
replace schooldegree_h_gpa=round(schooldegree_h_gpa,.1)
lab var schooldegree_h_gpa "GPA highest school-leaving degree"
lab val schooldegree_h_gpa schoolgpa
drop temp

* first vocational degree 
bys ID_t: egen temp1=min(month) if inrange(vocdegree,1,4) | vocdegree==.n
replace temp1=. if temp1!=month
replace temp1=vocdegree if temp1!=. // if any vocational degree
replace temp1=99 if temp1==.n // when first degree is unknown
bys ID_t: egen vocdegree_1=max(temp1)
recode vocdegree_1 99=.n 
bys ID_t: egen temp2=max(vocdegree) if vocdegree_1==., missing
replace vocdegree_1=temp2 if vocdegree_1==. // if no vocational degree or no vocdegree information
lab var vocdegree_1 "first vocational degree"
lab val vocdegree_1 vocdegree
drop temp2
ta vocdegree_1,m 

* age and month first vocational degree
gen temp_age=agem if temp1<.
bys ID_t: egen vocdegree_1_agem=max(temp_age)
replace vocdegree_1_agem=.a if vocdegree_1==0
replace vocdegree_1_agem=.m if vocdegree_1==.m
lab def vocdegree_miss .a "no voc.degree" .m "case without any vocdegree information"
lab val vocdegree_1_agem vocdegree_miss
lab var vocdegree_1_agem "age in months first vocational degree"
gen vocdegree_1_agey=vocdegree_1_agem/12
lab val vocdegree_1_agey vocdegree_miss
lab var vocdegree_1_agey "age in years first vocational degree"
gen temp_month=month if temp1<.
bys ID_t: egen vocdegree_1_month=max(temp_month)
replace vocdegree_1_month=.a if vocdegree_1==0
replace vocdegree_1_month=.m if vocdegree_1==.m
format vocdegree_1_month %tm
lab var vocdegree_1_month "month (since 01/1960) first vocational degree"
lab val vocdegree_1_month vocdegree_miss
drop temp*

* highest vocational degree 
bys ID_t: egen vocdegree_h=max(vocdegree)
bys ID_t: egen temp1=max(vocdegree) if vocdegree_h==. | vocdegree_h==0, missing
replace vocdegree_h=temp1 if (vocdegree_h==.|vocdegree_h==0) & inlist(temp1,.m,.n) // cases without any information on vocational degrees
lab var vocdegree_h "highest vocational degree"
lab val vocdegree_h vocdegree
drop temp1 
ta vocdegree_h,m 

* age and month highest vocational degree
bys ID_t: egen temp_age=min(agem) if vocdegree_h==vocdegree & !inlist(vocdegree_h,0,.m)
bys ID_t: egen vocdegree_h_agem=max(temp_age)
replace vocdegree_h_agem=.a if vocdegree_h==0
replace vocdegree_h_agem=.m if vocdegree_h==.m
lab val vocdegree_h_agem vocdegree_miss
lab var vocdegree_h_agem "age in months highest vocational degree"
gen vocdegree_h_agey=vocdegree_h_agem/12
lab val vocdegree_h_agey vocdegree_miss
lab var vocdegree_h_agey "age in years highest vocational degree"
bys ID_t: egen temp_month=min(month) if vocdegree_h==vocdegree & !inlist(vocdegree_h,0,.m)
bys ID_t: egen vocdegree_h_month=max(temp_month)
replace vocdegree_h_month=.a if vocdegree_h==0
replace vocdegree_h_month=.m if vocdegree_h==.m
format vocdegree_h_month %tm
lab var vocdegree_h_month "month (since 01/1960) highest vocational degree"
lab val vocdegree_h_month vocdegree_miss
drop temp*


*** TRANSFER DATA INTO INFORMATION-BY-AGE FORMAT *******************************

*** save data before changing format
compress
save "${savedta}\educ_prep_long.dta", replace   

*** generate age variable indicating full years
gen agefy=floor(agey)
tab agefy,m // negative age values for 9 respondents

*** generate maximum educational attainment variables per age year (range: 10-75)
drop if agefy<10 // exclude observations for age<10
foreach var of varlist schooldegree schooldegree_imp schooldegree_abroad schooldegree_add vocdegree vocdegree_imp vocdegree_abroad vocdegree_add educdegree{
   bys ID_t agefy: egen `var'_a=max(`var')
   bys ID_t agefy: egen `var'_b=max(`var'), missing  
   replace `var'_a=`var'_b if `var'_a==.
   lab def `var' .o"out of empirical data range", modify
   lab val `var'_a `var'
   drop `var' `var'_b
   ren `var'_a `var'_
   }
lab var schooldegree_ "highest school leaving degree"
lab var schooldegree_imp_ "imputation predictor for schooldegree"
lab var schooldegree_abroad_ "highest school-leaving degree obtained abroad"  
lab var schooldegree_add_ "new school-leaving degree obtained"
lab var vocdegree_ "highest school leaving degree"
lab var vocdegree_imp_ "imputation predictor for schooldegree"
lab var vocdegree_abroad_ "highest school-leaving degree obtained abroad"  
lab var vocdegree_add_ "new school-leaving degree obtained"
lab var educdegree_ "highest combined school/vocational degree"

*** transfer into wide format

* indicator of youngest and oldest age when schooldegree and vocdegree information are available
gen temp1=agefy if inlist(schooldegree_,1,2,3,4,5,6,.n)
bys ID_t: egen schoolage_min=min(temp1)
replace schoolage_min=.n if schoolage_min==. & schooldegree_1==0
replace schoolage_min=.m if schoolage_min==. & schooldegree_1==.m
lab def noinfo .n"no degree" .m"case without any degree information"
lab val schoolage_min noinfo
lab var schoolage_min "youngest age with school-leaving degree information"
bys ID_t: egen schoolage_max=max(temp1)
replace schoolage_max=.n if schoolage_max==. & schooldegree_h==0
replace schoolage_max=.m if schoolage_max==. & schooldegree_h==.m
lab val schoolage_max noinfo
lab var schoolage_max "oldest age with school-leaving degree information"
gen temp2=agefy if inlist(vocdegree_,1,2,3,4,.n)
bys ID_t: egen vocage_min=min(temp2)
replace vocage_min=.n if vocage_min==. & vocdegree_1==0
replace vocage_min=.m if vocage_min==. & inlist(vocdegree_1,.n,.m)
lab val vocage_min noinfo
lab var vocage_min "youngest age with vocational degree information"
bys ID_t: egen vocage_max=max(temp2)
replace vocage_max=.n if vocage_max==. & vocdegree_h==0
replace vocage_max=.m if vocage_max==. & inlist(vocdegree_h,.n,.m)
lab val vocage_max noinfo
lab var vocage_max "oldest age with vocational degree information"
drop temp1 temp2

* keep relevant observations, relevant variables and keep one row per month
bys ID_t agefy: gen n=_n
keep if n==1 
drop n month birthdate agem agey schoolgpa schooldegree_cum migration_age vocdegree_cum 

* reshape into wide format
reshape wide schooldegree_ schooldegree_imp_ schooldegree_abroad_ schooldegree_add_ vocdegree_ vocdegree_imp_ vocdegree_abroad_ vocdegree_add_ educdegree_, i(ID_t) j(agefy)
qui sum vocage_max
local max=r(max)
foreach var of varlist schooldegree_10- educdegree_`max'{
   replace `var'=.o if `var'==.
   }

* label variables
qui sum vocage_max
local max=r(max)
foreach i of numlist 10/`max'{   
   lab var schooldegree_`i' "highest school leaving degree at age `i'"
   lab var schooldegree_imp_`i' "imputation predictor for schooldegree age `i'"
   lab var schooldegree_abroad_`i' "highest school-leaving degree obtained abroad age `i'"
   lab var schooldegree_add_`i' "new school-leaving degree obtained at age `i'"
   lab var vocdegree_`i' "highest school leaving degree at age `i'"
   lab var vocdegree_imp_`i' "imputation predictor for schooldegree age `i'"
   lab var vocdegree_abroad_`i' "highest school-leaving degree obtained abroad age `i'"
   lab var vocdegree_add_`i' "new school-leaving degree obtained at age `i'" 
   lab var educdegree_`i' "highest combined school/vocational degree at age `i'"   
   } 

* order variables
order ID_t schoolage* vocage* schooldegree_1 schooldegree_1_agem schooldegree_1_agey schooldegree_1_month schooldegree_1_gpa vocdegree_1 vocdegree_1_agem vocdegree_1_agey vocdegree_1_month schooldegree_h* vocdegree_h* schooldegree_imp* schooldegree_abroad* schooldegree_add* vocdegree_imp* vocdegree_abroad* vocdegree_add* educdegree*
order schooldegree_10-vocdegree_`max', seq
order ID_t schoolage* vocage* schooldegree_1 schooldegree_1_agem schooldegree_1_agey schooldegree_1_month schooldegree_1_gpa vocdegree_1 vocdegree_1_agem vocdegree_1_agey vocdegree_1_month schooldegree_h* vocdegree_h*
 

*** SAVE DATA ******************************************************************
compress
save "${savedta}\educ_prep.dta", replace	
exit

