********************************************************************************
* Generate imputation syntax and impute data                                   *
*                                                                              *    
* Felix Bittmann, 22/07/2024, felix.bittmann@lifbi.de                          *
********************************************************************************


clear all
set maxvar 32000
use "${savedta}\prep_imp40.dta"

cap log close
log using "${savelog}\logfile_imputation.txt", text replace
*** Delete all unwanted vars ***
global allvars ID_t ///
	schooldegree_1 ///
	vocdegree_1 ///
	schooldegree_1_gpa ///
	status_educ_15-status_educ_40 ///
	status_emp_15-status_emp_40 ///
	schooldegree_15-schooldegree_40 ///
	vocdegree_15-vocdegree_40 ///
	casmin_p ///
	egp3_p ///
	isei_p ///
	gross_earn_32-gross_earn_48 ///
	gross_bonus_32-gross_bonus_48 ///
	net_earn_32-net_earn_48 ///
	workhours_32-workhours_48 ///
	partfirst partlast partnum birthyear gender migration_gen3 ///
	workh20_15-workh20_40 isei_15-isei_40 eastwest_15-eastwest_40 ///
	pubserv_15-pubserv_40 empmonths_15-empmonths_40 ///
	selfemp_15-selfemp_40
keep $allvars


*** Declare cases to be imputed ***
foreach VAR of varlist _all {
	replace `VAR' = . if inlist(`VAR', .z, .y)
}

*** Conditionals setzen ***
foreach VAR of varlist gross_earn_40 gross_bonus_40 net_earn_40 workhours_40 {
	replace `VAR' = 0 if status_emp_40 == 0
}

foreach VAR of newlist workh20_ isei_ eastwest_ pubserv_ empmonths_ selfemp_ {
	foreach AGE of numlist 15(1)40 {
		replace `VAR'`AGE' = 0 if status_emp_`AGE' == 0
		replace `VAR'`AGE' = . if missing(status_emp_`AGE')
	}
}

*** Prepare schooldegree_1_gpa as it only has values if schooldegree_1 is observed
replace schooldegree_1_gpa = 0 if !inrange(schooldegree_1, 1, 6)
replace schooldegree_1_gpa = . if missing(schooldegree_1)


*** Compute Wage Medians as Auxils ***
foreach VAR of newlist gross_earn_ gross_bonus_ net_earn_ workhours_ {
	egen `VAR'auxlow = rowmedian(`VAR'32-`VAR'39)
	egen `VAR'auxhigh = rowmedian(`VAR'41-`VAR'44)		//This will not be used
	sum `VAR'auxlow `VAR'auxhigh `VAR'40
}


*** Generate Imputation Dofile and run it ***
***For a final analysis dataset, I suggest 50 imputations with a 20 burnin***
python script "${dofile}\build_model2.py"		//Run directly from Stata or manually
do "${dofile}\dofile_imputation.do"


*** Save File ***
summarize *
compress
save "${savedta}\imputed_dataset_50.dta", replace
cap log close

exit

































