********************************************************************************
* Recode income data                                                           *
*                                                                              *    
* Steffen Schindler, 15/06/2025                                                *
********************************************************************************

clear
set more off
cap log close

version 16.1

use "${savedta}\income_plausi.dta"


*** BASIC RECODES **************************************************************


*** monthly gross earnings

* adjust categorical gross earnings (ts23511_g1) when missing  
ta ts23511_g1 ts23512 if ts23511==1, m // ts23511 below 1,500EUR
replace ts23511_g1=1 if ts23511_g1==.l & ts23512==1
replace ts23511_g1=2 if (ts23511_g1==.l & ts23512==2) | (ts23511==1 & inlist(ts23512,.b,.c))
replace ts23511_g1=3 if ts23511_g1==.l & ts23512==3
ta ts23511_g1 ts23513 if ts23511==2, m // ts23511 1,500-3,000EUR 
replace ts23511_g1=4 if ts23511_g1==.l & ts23513==1
replace ts23511_g1=5 if (ts23511_g1==.l & ts23513==2) | (ts23511==2 & inlist(ts23513,.b,.c))
replace ts23511_g1=6 if ts23511_g1==.l & ts23513==3
ta ts23511_g1 ts23514 if ts23511==3, m // ts23511 more than 3,000EUR
replace ts23511_g1=7 if ts23511_g1==.l & ts23514==1
replace ts23511_g1=8 if (ts23511_g1==.l & ts23514==2) | (ts23511==3 & inlist(ts23514,.b,.c))
replace ts23511_g1=9 if ts23511_g1==.l & ts23514==3
ta ts23511_g1 ts23512, m
ta ts23511_g1 ts23513, m
ta ts23511_g1 ts23514, m 

* generate metric earnings values from categories by assigning the mean values of the categories (when exact figures are absent)
cap drop gross_earn net_earn
gen gross_earn=ts23510 
lab val gross_earn enmiss
lab var gross_earn "gross monthly earnings"
tabstat gross_earn, by(ts23511_g1) stat(n mean median) // check empirical means and medians within earnings categories
table wave ts23511_g1, c(mean gross_earn) format(%9.0f) // not much variation in mean values across waves
levelsof ts23511_g1, local(level)
foreach l of local level{
   sum gross_earn if ts23511_g1==`l' 
   replace gross_earn=r(mean) if gross_earn>=. & ts23511_g1==`l' // assign mean values from observations with metric earnings information
   }
replace gross_earn=floor(gross_earn)
tabstat gross_earn if ts23510>=., by(ts23511_g1) stat(mean median N)

* Child allowance included in gross payments
ta ts23522 ts23521, m // --> cross-check missing categories with information on childlessness  
gen gross_child=ts23522
replace gross_child=0 if ts23521==2
replace gross_child=.a if gross_child>=. & inlist(ts23521,.,.b,.c,.l)
replace gross_child=.b if gross_child>10 & gross_child<. // set implausible values to missing
replace gross_child=.b if gross_child==.c // merge missing categories 
lab def gross_child .a "unknown if child allowance included" .b "number of child allowances unknown" .m "missing by design"
lab val gross_child gross_child
lab var gross_child "number child allowance payments included in gross earnings"
ta gross_child ts23521, m 
ta gross_child ts23522, m 
ta gross_child children,m  // use number of children in the household as a proxi (no other information about children available)
replace gross_child=0 if children==0 & gross_child>=.
ta gross_child, m 


*** Special payments (gross bonus payments)

* auxiliary variable: bonus payments as a precentage of regular monthly gross earnings (by earnings category) 
gen temp1a=ts23541/gross_earn              // percentage 13th month salary
bys ts23511_g1: egen temp1b=mean(temp1a)   // average percentage per earnings category
tab ts23511_g1, sum(temp1b)
gen temp2a=ts23542/gross_earn              // percentage 14th month salary
bys ts23511_g1: egen temp2b=mean(temp2a)   // average percentage per earnings category
tab ts23511_g1, sum(temp2b)
gen temp3a=ts23543/gross_earn              // percentage christmas bonus
bys ts23511_g1: egen temp3b=mean(temp3a)   // average percentage per earnings category
tab ts23511_g1, sum(temp3b)
gen temp4a=ts23544/gross_earn              // percentage holiday bonus
bys ts23511_g1: egen temp4b=mean(temp4a)   // average percentage per earnings category
tab ts23511_g1, sum(temp4b)
gen temp5a=ts23545/gross_earn              // percentage profit sharing
bys ts23511_g1: egen temp5b=mean(temp5a)   // average percentage per earnings category
tab ts23511_g1, sum(temp5b)
gen temp6a=ts23546/gross_earn              // percentage other special payment
bys ts23511_g1: egen temp6b=mean(temp6a)   // average percentage per earnings category
tab ts23511_g1, sum(temp6b)

* replace missing values on bonus payments with averages (within earnings categories)
replace ts23541=temp1b*gross_earn if ts23531==1 & ts23541>=. 
replace ts23542=temp1b*gross_earn if ts23532==1 & ts23542>=.
replace ts23543=temp1b*gross_earn if ts23533==1 & ts23543>=.
replace ts23544=temp1b*gross_earn if ts23534==1 & ts23544>=.
replace ts23545=temp1b*gross_earn if ts23535==1 & ts23545>=.
replace ts23546=temp1b*gross_earn if ts23536==1 & ts23546>=.

* [EDIT 10/03/2025] original code contains error, the correct code is as follows:  
* replace missing values on bonus payments with averages (within earnings categories)
// replace ts23541=temp1b*gross_earn if ts23531==1 & ts23541>=. 
// replace ts23542=temp2b*gross_earn if ts23532==1 & ts23542>=.
// replace ts23543=temp3b*gross_earn if ts23533==1 & ts23543>=.
// replace ts23544=temp4b*gross_earn if ts23534==1 & ts23544>=.
// replace ts23545=temp5b*gross_earn if ts23535==1 & ts23545>=.
// replace ts23546=temp6b*gross_earn if ts23536==1 & ts23546>=.

* generate variable indicating bonus payments (average per month)
egen gross_bonus_=rowtotal(ts23541 ts23542 ts23543 ts23544 ts23545 ts23546) // calculate bonus total
replace gross_bonus_=gross_bonus_/12 // calculate bonus per month 
replace gross_bonus_=.a if ts23541>=. & ts23542>=. & ts23543>=. & ts23544>=. & ts23545>=. & ts23546>=.
replace gross_bonus_=0 if ts23531==2 & ts23532==2 & ts23533==2 & ts23534==2 & ts23535==2 & ts23536==2
lab var gross_bonus_ "special payments (per month)"
lab def indet .a "indeterminate"
lab val gross_bonus_ indet
cap drop temp*
* generate variable indicating lower-bound number of bonus payments (uneven categories indcate uncertainty through missing information) 
forvalues i=1/6{ 
   recode ts2353`i' (2=0), into(temp_a`i') copyrest
   recode ts2353`i' (1 2=0) (else=1), into(temp_b`i')
   } 
egen gross_bonus_n=rowtotal(temp_a1 temp_a2 temp_a3 temp_a4 temp_a5 temp_a6)  
egen temp_c=rowtotal(temp_b1 temp_b2 temp_b3 temp_b4 temp_b5 temp_b6)
replace gross_bonus_n=gross_bonus_n*2
lab def gross_bonus_n ///
0 "0 bonus payments" ///
1 "0 or more" ///
2 "1 bonus payment" ///
3 "1 or more" ///
4 "2 bonus payments" ///
5 "2 or more" ///
6 "3 bonus payments" ///
7 "3 or more" ///
8 "4 bonus payments" ///
9 "4 or more" ///
10 "5 bonus payments" ///
11 "5 or more" ///
12 "6 bonus payments" ///
.a "indeterminate"
replace gross_bonus_n=1 if gross_bonus_n==0 & inrange(temp_c,1,6)
replace gross_bonus_n=3 if gross_bonus_n==2 & inrange(temp_c,1,6)
replace gross_bonus_n=5 if gross_bonus_n==4 & inrange(temp_c,1,6)
replace gross_bonus_n=7 if gross_bonus_n==6 & inrange(temp_c,1,6)
replace gross_bonus_n=9 if gross_bonus_n==8 & inrange(temp_c,1,6)
replace gross_bonus_n=11 if gross_bonus_n==10 & inrange(temp_c,1,6)
lab var gross_bonus_n "number of different bonus payments"
lab val gross_bonus_n gross_bonus_n 

* generate variable (number of bonus payments) that can be used as a predictor for missings on bonus payments  
recode gross_bonus_n (0 1=0 "0 or more") (2 3=1 "1 or more") (4 5=2 "2 or more") (6 7=3 "3 or more") ///
(8 9=4 "4 or more") (10 11 12=5 "5 or more"), into(gross_bonus_imp) 
lab var gross_bonus_imp "number of different bonus payments (for imputation)"

* generate variable indicating total bonus payments including missings to be imputed
gen gross_bonus=gross_bonus_ // generate special payments variable with missings to be imputed
replace gross_bonus=.a if inlist(gross_bonus_n,1,3,5,7,9,11)
lab var gross_bonus "total special payments (to be imputed)"
ta gross_bonus_n, sum(gross_bonus)
lab val gross_bonus indet


*** monthly net earnings 

* generate metric earnings values from categories by assigning the mean values of the categories (when exact figures are absent)
gen net_earn=ts23410 
lab val net_earn enmiss
lab var net_earn "net monthly earnings"
tabstat net_earn, by(ts23411_g1) stat(mean median) // check empirical means and medians within earnings categories
table wave ts23411_g1, c(mean net_earn) format(%9.0f) // not much variation in mean values across waves
levelsof ts23411_g1, local(level)
foreach l of local level{
   sum net_earn if ts23411_g1==`l' 
   replace net_earn=r(mean) if net_earn>=. & ts23411_g1==`l' // assign mean values from observations with metric earnings information
   }
replace net_earn=floor(net_earn)
tabstat net_earn if ts23410>=., by(ts23411_g1) stat(mean median N)


*** working hours (actual)
gen workhours=ts23223_g1
replace workhours=.a if workhours>=.
lab val workhours indet
lab var workhours "actual working hours per week" 
ta workhours ts23223_g1 if ts23223_g1>=., m


*** RECODES DEALING WITH PARALLEL JOB SPELLS ***********************************

*** indicators of number of job spells and spells with non-missing data 

* generate indicator of number of parallel jobs
cap drop p n nn count
bys ID_t wave: gen p=_N 
bys ID_t: egen pp=max(p) 
bys ID_t wave: gen n=_n // number of parallel spell

* count number of non-missing gross earnings spells per waves
bys ID_t wave: egen temp1=count(gross_earn)  

* count number of non-missing working hours spells per wave
bys ID_t wave: egen temp2=count(workhours)  

* count number of non-missing special payment spells per wave
bys ID_t wave: egen temp3=count(gross_bonus)  

* count number of non-missing net earnings spells per waves
bys ID_t wave: egen temp4=count(net_earn)  


*** number of jobs, total earnings, working hours and special payments across parallel spells

* generate number of parallel jobs
gen jobs=p
lab val jobs indet
lab var jobs "number of parallel jobs"

* generate total gross earnings variable per wave 
bys ID_t wave: egen gross_earn_c=total(gross_earn) 
replace gross_earn_c=.a if temp1==0
lab var gross_earn_c "net monthly earnings (total)" 
lab val gross_earn_c indet 

* generate total net earnings variable per wave 
bys ID_t wave: egen net_earn_c=total(net_earn) 
replace net_earn_c=.a if temp4==0
lab var net_earn_c "net monthly earnings (total)" 
lab val net_earn_c indet 

* generate total working hours variable per wave 
bys ID_t wave: egen workhours_c=total(workhours) 
replace workhours_c=.a if temp2==0
lab var workhours_c "working hours per week (total)" 
lab val workhours_c indet 
bys ID_t: egen temp5=max(workhours_c)
//list ID_t splink wave start end gross_earn gross_earn_c temp1 workhours workhours_c temp2 n if temp5>90, sepby(ID_t)
replace workhours=.a if workhours_c>90 & workhours_c<. // set to missing if working hours implausible 
replace workhours_c=.a if workhours_c>90 & workhours_c<.
ta workhours,m
ta workhours_c if p==1,m
drop temp2 temp5
bys ID_t wave: egen temp2=count(workhours)  // update count of non-missing spells per wave 

* recode gross earnings and working time variables (cumulated over parallel jobs) - set to missing if no or incomplete information
  // 1) no missings on earnings - no missings on working hours --> OK
  // 2) no missings on earnings - partial missings on working hours --> set working hours to missing
  // 3) no missings on earnings - complete missings on working hours --> set working hours to missing
  // 4) partial missings on earnings - no missings on working hours --> set earnings to missing 
  // 5) partial missings on earnings - partial missings on working hours --> set earnings and working hours to missing 
  // 6) partial missings on earnings - complete missings on working hours --> set earnings and working hours to missing 
  // 7) complete missings on earnings - no missings on working hours --> set earnings to missing 
  // 8) complete missings on earnings - partial missings on working hours --> set earnings and working hours to missing  
  // 9) complete missings on earnings - complete missings on working hours --> set earnings and working hours to missing 
clonevar temp_gross_earn_c=gross_earn_c
clonevar temp_workhours_c=workhours_c
replace workhours_c=.a if temp1==p & temp2<p & temp2>0           // 2)
replace workhours_c=.a if temp1==p & temp2==0                    // 3) 
replace gross_earn_c=.a if temp1<p & temp1>0 & temp2==p          // 4)
replace gross_earn_c=.a if temp1<p & temp1>0 & temp2<p & temp2>0 // 5)
replace workhours_c=.a if temp1<p & temp1>0 & temp2<p & temp2>0  // 5)
replace gross_earn_c=.a if temp1<p & temp1>0 & temp2==0          // 6)
replace workhours_c=.a if temp1<p & temp1>0 & temp2==0           // 6)
replace gross_earn_c=.a if temp1==0 & temp2==p                   // 7) 
replace gross_earn_c=.a if temp1==0 & temp2<p & temp2>0          // 8) 
replace workhours_c=.a if temp1==0 & temp2<p & temp2>0           // 8) 
replace gross_earn_c=.a if temp1==0 & temp2==0                   // 9)
replace workhours_c=.a if temp1==0 & temp2==0                    // 9)
// list ID_t splink wave start end gross_earn temp_gross_earn_c gross_earn_c temp1 workhours temp_workhours_c workhours_c temp2 p if pp>1, sepby(ID_t)

* generate total monthly special payments (boni) per wave 
bys ID_t wave: egen gross_bonus_c=total(gross_bonus_) 
replace gross_bonus_c=.a if temp3==0 
clonevar temp_gross_bonus_c=gross_bonus_c
replace gross_bonus_c=.a if temp3<p  
lab var gross_bonus_c "gross monthly special payments (total)" 
lab val gross_bonus_c indet 
// list ID_t splink wave start end intmonth earnmonth gross_bonus gross_bonus_n gross_bonus_c temp3 p, sepby(ID_t)

* recode net earnings variable (cumulated over parallel jobs) - set to missing if no or incomplete information
clonevar temp_net_earn_c=net_earn_c
replace net_earn_c=.a if temp4<p & temp4>=0


*** recode variables that can be used as predictors for imputation

* generate categorical variable indicating total monthly gross earnings that can be used as predictor for imputation 
tab temp_gross_earn_c if n==1, m
recode temp_gross_earn_c ///
(0/500=0 "0 or more") ///
(501/1000=1 "more than 500") ///
(1001/2000=2 "more than 1000") ///
(2001/3000=3 "more than 2000") ///
(3001/4000=4 "more than 3000") ///
(4001/5000=5 "more than 4000") ///
(5001/6000=6 "more than 5000") ///
(6001/7000=7 "more than 6000") ///
(7001/8000=8 "more than 7000") ///
(8001/10000=9 "more than 8000") ///
(10001/max=10 "more than 10000") ///
(.a=.a "identerminate") ///
, into(gross_earn_c_imp)
lab var gross_earn_c_imp "total gross monthly earnings (categories for imputation)"
tab gross_earn_c_imp if gross_earn_c<. & n==1, m
tab gross_earn_c_imp if n==1, sum(gross_earn_c)

* generate categorical variable indicating total working hours that can be used as predictor for imputation 
tab temp_workhours_c if n==1, m
recode temp_workhours_c ///
(0/10=0 "0 or more") ///
(10/20=1 "10 or more") ///
(20/30=2 "20 or more") ///
(30/40=3 "30 or more") ///
(40/50=4 "40 or more") ///
(50/60=5 "50 or more") ///
(60/70=6 "60 or more") ///
(70/80=7 "70 or more") ///
(80/90=8 "80 or more") ///
(.a=.a "indeterminate") ///
, into(workhours_c_imp)
lab var workhours_c_imp "total weekly working hours (categories for imputation)"
tab workhours_c_imp if workhours_c==.a & n==1, m
tab workhours_c_imp, sum(workhours_c)

* generate categorical variable indicating total monthly special payments that can be used as predictor for imputation 
tab temp_gross_bonus_c if n==1 & gross_bonus_c<.
recode temp_gross_bonus_c ///
(0/20=0 "0 or more") ///
(20/50=1 "20 or more") ///
(50/100=2 "50 or more") ///
(100/200=3 "100 or more") ///
(200/300=4 "200 or more") ///
(300/500=5 "300 or more") ///
(500/1000=6 "500 or more") ///
(1000/5000=7 "1000 or more") ///
(5000/max=8 "5000 or more") ///
(.a=.a "indeterminate") ///
, into(gross_bonus_c_imp) 
lab var gross_bonus_c_imp "total monthly special payments (categories for imputation)"
tab gross_bonus_c_imp if gross_bonus_c<. & n==1, m // only 110 observations in highest category
tab gross_bonus_c_imp if n==1, sum(gross_bonus_c)

* generate total number of monthly special payments (boni) per wave 
bys ID_t wave: egen gross_bonus_n_imp=total(gross_bonus_imp)
lab var gross_bonus_n_imp "total number of different bonus payments (for imputation)"
lab val gross_bonus_n_imp gross_bonus_imp
ta gross_bonus_n_imp if n==1, m
recode gross_bonus_n_imp (0 1=1) (2=2) (3=3) (4=4) (5/max=5)
lab def gross_bonus_n_imp 1"0 or more" 2"2 or more" 3"3 or more" 4"4 or more" 5"5 or more"
lab val gross_bonus_n_imp gross_bonus_n_imp
ta gross_bonus_n_imp if n==1 & gross_bonus_n<., m // only 253 observations in highest category
ta gross_bonus_n_imp if n==1, sum(gross_bonus_c)

* generate categorical variable indicating total monthly net earnings that can be used as predictor for imputation 
tab temp_net_earn_c if n==1, m
recode temp_net_earn_c ///
(0/500=0 "0 or more") ///
(501/1000=1 "more than 500") ///
(1001/1500=2 "more than 1000") ///
(1501/2000=3 "more than 1500") ///
(2001/2500=4 "more than 2000") ///
(2501/3000=5 "more than 2500") ///
(3001/4000=6 "more than 3000") ///
(4001/6000=7 "more than 4000") ///
(6001/8000=8 "more than 6000") ///
(8001/max=9 "more than 8000") ///
(.a=.a "indenterminate") ///
, into(net_earn_c_imp)
lab var net_earn_c_imp "total net monthly earnings (categories for imputation)"
tab net_earn_c_imp if net_earn_c<. & n==1, m
tab net_earn_c_imp if n==1, sum(net_earn_c)


*** TRANSFER DATA INTO INFORMATION-BY-AGE FORMAT *******************************

*** save data in long format
compress
save "${savedta}\income_prep_long.dta", replace	

*** merge information on birth date
merge m:1 ID_t using "${savedta}\basicinfo.dta", nogen keep(1 3) keepusing(birthdate)

*** keep relevant variables and keep one row per wave
keep if n==1
keep ID_t wave jobs gross_earn_c net_earn_c workhours_c gross_bonus_c gross_earn_c_imp workhours_c_imp gross_bonus_c_imp gross_bonus_n_imp net_earn_c_imp birthdate earnmonth
rename *_c* **

*** generate variable indicating age when earnings were reported
* generate age at survey interview 
gen earnagem=earnmonth-birthdate
lab var earnagem "age when earnings were reported (in months)"
gen earnagey=earnagem/12
lab var earnagey "age when earnings were reported (in years)"
gen earnagefy=floor(earnagey) // rounded to floor integer 
lab var earnagefy "age when earnings were reported (in full years)"
* corrections if same age at two different waves
bys ID_t earnagefy: gen a=_n
bys ID_t earnagefy: gen aa=_N
bys ID_t: egen aaa=max(a)
ta a,m
sort ID_t wave earnagem
gen temp1a=earnagefy-earnagefy[_n-1] if ID_t==ID_t[_n-1] & wave==wave[_n-1]+1 // gap between age value and age value in previous row
gen temp1b=earnagefy[_n+1]-earnagefy if ID_t==ID_t[_n+1] & wave==wave[_n+1]-1 // gap between age value and age value in subsequent row
replace earnagefy=round(earnagey) if temp1a==0 & temp1b==2 // round to closest integer (ceil) if 2 year gap to subsequent spell and no gap to previous spell
* drop when multiple rows per age 
drop a aa aaa // update indicators of numbers of rows with same age
bys ID_t earnagefy: gen a=_n
bys ID_t earnagefy: gen aa=_N
bys ID_t earnagefy: egen gross_earn_max=max(gross_earn) if aa>1 // keep rows with highest gross earnings
drop if gross_earn!=gross_earn_max & aa>1 & gross_earn_max<.
drop a aa // update indicators of numbers of rows with same age
bys ID_t earnagefy: gen a=_n
bys ID_t earnagefy: gen aa=_N
bys ID_t earnagefy: egen net_earn_max=max(net_earn) if aa>1 // keep rows with highest gross earnings
drop if net_earn!=net_earn_max & aa>1 & net_earn_max<.
drop a aa // update indicators of numbers of rows with same age
bys ID_t earnagefy: gen a=_n
bys ID_t earnagefy: gen aa=_N
bys ID_t earnagefy: egen gross_bonus_max=max(gross_bonus) if aa>1 // keep rows with highest values on special payments
drop if gross_bonus!=gross_bonus_max & aa>1 & gross_bonus_max<.
drop a aa // update indicators of numbers of rows with same age
bys ID_t earnagefy: gen a=_n
bys ID_t earnagefy: gen aa=_N
bys ID_t earnagefy: egen gross_earn_imp_max=max(gross_earn_imp) if aa>1 // keep rows with highest values on gross_earn_imp
drop if gross_earn_imp!=gross_earn_imp_max & aa>1 & gross_earn_imp_max<.
drop a aa // update indicators of numbers of rows with same age
bys ID_t earnagefy: gen a=_n
bys ID_t earnagefy: gen aa=_N
bys ID_t earnagefy: egen net_earn_imp_max=max(net_earn_imp) if aa>1 // keep rows with highest values on gross_earn_imp
drop if net_earn_imp!=net_earn_imp_max & aa>1 & net_earn_imp_max<.
drop a aa // update indicators of numbers of rows with same age
bys ID_t earnagefy: gen a=_n
bys ID_t earnagefy: gen aa=_N
drop if aa>1 & a<aa // among remaining multiple rows per age: keep most recent information 

*** generate information-by-age variables

* indicator of youngest and oldest age when information are available
bys ID_t: egen earnage_min=min(earnagefy)
lab var earnage_min "youngest age with earnings information"
bys ID_t: egen earnage_max=max(earnagefy)
lab var earnage_max "oldest age with earnings information"

* modify labels
foreach l in indet gross_earn_c_imp workhours_c_imp gross_bonus_c_imp gross_bonus_n_imp net_earn_c_imp{ 
   lab def `l' .o "out of empirical data range", modify
   }

* reshape into wide format
keep ID_t earnagefy jobs gross_earn net_earn workhours gross_bonus gross_earn_imp workhours_imp gross_bonus_imp gross_bonus_n_imp net_earn_imp earnage_min earnage_max
foreach var of varlist jobs gross_earn net_earn workhours gross_bonus gross_earn_imp workhours_imp gross_bonus_imp gross_bonus_n_imp net_earn_imp{
   rename `var' `var'_
   }
reshape wide jobs gross_earn_ net_earn_ workhours_ gross_bonus_ gross_earn_imp_ workhours_imp_ gross_bonus_imp_ gross_bonus_n_imp_ net_earn_imp_, i(ID_t) j(earnagefy)
qui sum earnage_min
local min=r(min)
qui sum earnage_max
local max=r(max)
foreach var of varlist gross_earn_`min'-net_earn_imp_`max'{
   replace `var'=.o if `var'==.
   }
* label variables
qui sum earnage_min
local min=r(min)
qui sum earnage_max
local max=r(max)
foreach i of numlist `min'/`max'{ 
   lab var jobs_`i' "number of jobs age `i'"
   lab var gross_earn_`i' "gross monthly earnings age `i'"
   lab var net_earn_`i' "net monthly earnings age `i'"
   lab var gross_bonus_`i' "special payments age `i' (per month)"   
   lab var workhours_`i' "total weekly working hours age `i'"
   lab var gross_earn_imp_`i' "gross monthly earnings categories age `i' (for impitation)"
   lab var net_earn_imp_`i' "net monthly earnings categories age `i' (for impitation)"
   lab var gross_bonus_imp_`i' "special payments per month age `i' (for imputation)"   
   lab var gross_bonus_n_imp_`i' "number of different bonus payments age `i' (for imputation)" 
   lab var workhours_imp_`i' "total weekly working hours categories age `i' (for imputation)"
   } 
* order variables
order _all, seq
qui sum earnage_min
local min=r(min)
qui sum earnage_max
local max=r(max)
order ID_t earnage_min earnage_max jobs_`min'-jobs_`max' gross_earn_`min'-gross_earn_`max' net_earn_`min'-net_earn_`max' ///     
      gross_bonus_`min'-gross_bonus_`max' workhours_`min'-workhours_`max' gross_earn_imp_`min'-gross_earn_imp_`max' net_earn_imp_`min'-net_earn_imp_`max' ///
	  gross_bonus_imp_`min'-gross_bonus_imp_`max' gross_bonus_n_imp_`min'-gross_bonus_n_imp_`max' workhours_imp_`min'-workhours_imp_`max'


*** Save data ******************************************************************
compress
save "${savedta}\income_prep.dta", replace	
exit







