********************************************************************************
* Recode monthly biography information                                 		   *
*      							                                               *    
* Steffen Schindler, 15/06/2025                               				   *
********************************************************************************

clear
capture log close
version 13
set more off, perm
set scrollbufsize  50000


********************************************************************************
* Generate monthly biography information 
********************************************************************************
use "${savedta}\SC6_Biography_D_${SUF}.dta", clear

* check date
fre starty endy startm endm
egen missy = rowmiss(starty endy)
egen missm = rowmiss(startm endm)
fre missy missm

* delete episodes with missing information on dates
drop if missy>0 | missm>0
drop missy missm

* recode indicators of episode's start and end in YM format 
gen start = ym(starty,startm)
gen end = ym(endy,endm)
format start end %tm
lab var start "start in months since Jan 1960"
lab var end "end in months since Jan 1960"

* generate duration of episode
gen dur = end-start+1
sum dur, detail // OK

* delete unnecessary variables
drop wave splast-endy

* count number of episodes per person
sort ID_t start end 
by ID_t: gen epinr = [_n]
fre epinr 

* expand data (monthly information)
sort ID_t start end
expand dur
sort ID_t epinr

* consecutive number of month by episode
by ID_t epinr: gen monnr = [_n]

* generate variable indicating month since Jan 1960
gen month = start+monnr-1
format month %tm
lab var month "month since Jan 1960"

* delete unnecessary variables
drop start end dur epinr monnr

* counter for multiple months 
sort ID_t month sptype splink // within months: sort by module first and then by number of spell
by ID_t month: gen monthnr = [_n]

* check for peculiar cases
fre monthnr 
gen temp1=1 if monthnr>5
drop temp* monthnr

* sort information in multiple spells per month by
* a) main and secondary activities, 
* b) types of episodes which usually don't allow for secondary activity come first
recode sptype 22=2 23=4 24=3 25=1 26=8 27=5 29=6 30=7 99=9, gen(spsort)
sort ID_t month spms spsort splink 
drop spsort
by ID_t month: gen monthnr = [_n] 

* generate duration of episodes
bys ID_t splink: gen dur= [_N]


*** save dataset ***************************************************************
sort ID_t month monthnr
save "${savedta}\month_episodes", replace
exit 


