********************************************************************************
* Recode occupation history                                                    *
*                                                                              *    
* Steffen Schindler, 15/06/2025                                                *
********************************************************************************

clear
set more off
cap log close

version 16.1

*** MERGE DATA *****************************************************************

use "${savedta}\month_episodes", clear

*** merge information on year of birth
merge m:1 ID_t using "${savedta}\basicinfo.dta", nogen keep(1 3) keepusing(birthdate)
* generate age in months and in years
gen agem=month-birthdate
lab var agem "age in months"
gen agey=(month-birthdate)/12
lab var agey "age in years"
gen agefy=floor(agey) 
lab var agefy "age in full years"
* generate variable indicatin number of rows per age
bys ID_t agefy: gen n=_n


*** RECODE VARIABLES ***********************************************************

*** recode information on employment/education status
gen temp_educ=1 if inlist(sptype,22,23,24)
gen temp_employed=1 if sptype==26
gen temp_unemployed=1 if sptype==27
gen temp_parleave=1 if sptype==29
gen temp_gap=1 if sptype==30
gen temp_mili=1 if sptype==25
gen temp_miss=1 if sptype==99
foreach var of varlist temp_educ temp_employed temp_unemployed temp_parleave temp_gap temp_mili temp_miss{
   bys ID_t month: egen `var'2=max(`var')
   }
lab def status ///
1 "missing" ///
2 "gap" ///
3 "military" ///
4 "education" ///
5 "unemployed" ///
6 "unemployed and parental leave" ///
7 "unemployed and education" ///
8 "parental leave" ///
9 "parental leave and education" ///
10 "employed" ///
11 "employed and unemployed" ///
12 "employed and parental leave" ///
13 "employed and education" 
gen status=1 if temp_miss2==1
replace status=2 if temp_gap2==1
replace status=3 if temp_mili2==1
replace status=4 if temp_educ2==1
replace status=5 if temp_unemployed2==1
replace status=6 if temp_unemployed2==1 & temp_parleave2==1
replace status=7 if temp_unemployed2==1 & temp_educ2==1
replace status=8 if temp_parleave2==1 & temp_unemployed2!=1
replace status=9 if temp_parleave2==1 & temp_educ2==1
replace status=10 if temp_employed2==1
replace status=11 if temp_employed2==1 & temp_unemployed2==1
replace status=12 if temp_employed2==1 & temp_parleave2==1
replace status=13 if temp_employed2==1 & temp_educ2==1
lab val status status
lab var status "education/employment status"


*** merge information on occupational status
gen subspell=0
merge m:1 ID_t splink subspell using "${savedta}\SC6_spEmp_D_${SUF}.dta", nogen keep(1 3) keepusing(ts23201_g14 ts23201_g8 ts23203 ts23241 ts23237_g2 ts23219_g1 ts23218 ts23223_g1)


*** recode occupation variables

* EGP
recode ts23201_g8 (1=11 "I") (2=10 "II") (3=9 "IIIa") (4=8 "IIIb") (5=7 "IVa") (6=6 "IVb") (7=5 "IVc") (8=4 "V") (9=3 "VI") (10=2 "VIIa") (11=1 "VIIb") /// 
(else=.), into(egp)
lab def egp .a"no information" .b"not employed other" .c"unemployed" .d"employed but no info on EGP" .o"out of empirical data range", modify
replace egp=.d if egp==. & inlist(status,10,11,12,13)
replace egp=.c if egp==. & inlist(status,5,6,7) 
replace egp=.b if egp==. & inlist(status,2,3,4,8,9) 
replace egp=.a if egp==. & status==1 
lab var egp "EGP class"

* ISEI
gen isei=ts23201_g14 if ts23201_g14<.
lab def isei .a"no information" .b"not employed other" .c"unemployed" .d"employed but no info on ISEI" .o"out of empirical data range"
replace isei=.d if isei==. & inlist(status,10,11,12,13)
replace isei=.c if isei==. & inlist(status,5,6,7) 
replace isei=.b if isei==. & inlist(status,2,3,4,8,9) 
replace isei=.a if isei==. & status==1 
lab val isei isei
lab var isei "ISEI-08"

* Professional status
recode ts23203 ///
(6=1 "assisting familiy member") ///
(8=2 "employment as preparation for a profession") ///
(7=3 "freelancer") ///
(5=4 "self-employed") ///
(4=5 "regular/professional soldier") ///
(1=6 "worker") ///
(2=7 "employee") ///
(3=8 "civil servant") ///
(else=.), into(profstatus)
lab def profstatus .a"no information" .b"not employed other" .c"unemployed" .d"employed but no info on professional status" .o"out of empirical data range", modify
replace profstatus=.d if profstatus==. & inlist(status,10,11,12,13)
replace profstatus=.c if profstatus==. & inlist(status,5,6,7) 
replace profstatus=.b if profstatus==. & inlist(status,2,3,4,8,9) 
replace profstatus=.a if profstatus==. & status==1 
lab val profstatus profstatus
lab var profstatus "professional status"

* Public service
recode ts23241 (1=1 "public service") (2=0 "private sector") (else=.), into(pubserv)
lab def pubserv .a"no information" .b"not employed other" .c"unemployed" .d"employed but no info on sector" .o"out of empirical data range", modify
replace pubserv=.d if pubserv==. & inlist(status,10,11,12,13)
replace pubserv=.c if pubserv==. & inlist(status,5,6,7) 
replace pubserv=.b if pubserv==. & inlist(status,2,3,4,8,9) 
replace pubserv=.a if pubserv==. & status==1 
lab val pubserv pubserv
lab var pubserv "public service or private sector"

* Location of work place (federal state)
ren ts23237_g2 fedwork
replace fedwork=. if inlist(fedwork,.b,.c,.l,.m) 
lab copy en1619ext1 fedwork
lab def fedwork 17"changing locations/abroad" .a"no information" .b"not employed other" .c"unemployed" .d"employed but no info on federal state" .l"" .m"" .o"out of empirical data range" .x"" .y"", modify
replace fedwork=17 if inlist(fedwork,.x,.y)
replace fedwork=.d if fedwork==. & inlist(status,10,11,12,13)
replace fedwork=.c if fedwork==. & inlist(status,5,6,7) 
replace fedwork=.b if fedwork==. & inlist(status,2,3,4,8,9) 
replace fedwork=.a if fedwork==. & status==1 
lab val fedwork fedwork
lab var fedwork "federal state of work place"

* working hours (contractual)
gen workh_c=ts23219_g1 if ts23219_g1<.
replace workh_c=20 if ts23218==2 & workh_c>=. // 20h if part-time
replace workh_c=40 if ts23218==1 & workh_c>=. // 40h if full-time
lab def workh_c .a"no information" .b"not employed other" .c"unemployed" .d"employed but no info on working hours" .e"exact wh unknown but 20h or more" .f"exact wh unkonwn but 40h or more" .o"out of empirical data range"
replace workh_c=.d if workh_c==. & inlist(status,10,11,12,13)
replace workh_c=.c if workh_c==. & inlist(status,5,6,7) 
replace workh_c=.b if workh_c==. & inlist(status,2,3,4,8,9) 
replace workh_c=.a if workh_c==. & status==1 
lab val workh_c workh_c
lab var workh_c "working hours (contractual)" 

* working hours (actual)
gen workh_a=ts23223_g1 if ts23223_g1<.
lab def workh_a .a"no information" .b"not employed other" .c"unemployed" .d"employed but no info on working hours" .e"exact wh unknown but 20h or more" .f"exact wh unkonwn but 40h or more" .o"out of empirical data range" 
replace workh_a=.d if workh_a==. & inlist(status,10,11,12,13)
replace workh_a=.c if workh_a==. & inlist(status,5,6,7) 
replace workh_a=.b if workh_a==. & inlist(status,2,3,4,8,9) 
replace workh_a=.a if workh_a==. & status==1 
lab val workh_a workh_a
lab var workh_a "working hours (actual)" 


*** TRANSFER DATA INTO INFORMATION-BY-AGE FORMAT *******************************

*** generate maximum per age for occupation variables (also for categorical variables)
foreach var of varlist status egp isei profstatus pubserv fedwork{
   bys ID_t agefy: egen `var'_1=max(`var')
   bys ID_t agefy: egen `var'_2=max(`var'), missing  
   replace `var'_1=`var'_2 if `var'_1==.
   lab val `var'_1 `var'
   drop `var' `var'_2
   ren `var'_1 `var'_
   }
recode egp (11=1) (10=2) (9=3) (8=4) (7=5) (6=6) (5=7) (4=8) (3=9) (2=10) (1=11) // return to initial coding of EGP variable
lab def egp 1"I" 2"II" 3"IIIa" 4"IIIb" 5"IVa" 6"IVb" 7"IVc" 8"V" 9"VI" 10"VIIa" 11"VIIb", modify 
lab var status_ "education/employment status"
lab var egp_ "EGP class"
lab var isei_ "ISEI-08"   
lab var profstatus_ "professional status"
lab var pubserv_ "public service or private sector"
lab var fedwork_ "federal state of work place"   

*** generate mean per age for working hours variables

* auxiliary variable: number of parallel employment spells per month (average per age)
bys ID_t month sptype: gen temp1=_n
bys ID_t month: egen temp2=max(temp1) if sptype==26
bys ID_t agefy temp1: egen temp3=mean(temp2) if temp1==1
bys ID_t agefy: egen emppara_=max(temp3)
replace emppara_=0 if emppara_==.
lab var emppara_ "average number of parallel monthly employment spells"  

* number of months in employment
gen temp4=1 if temp1==1 & sptype==26
bys ID_t agefy: egen empmonths_=total(temp4)
lab var empmonths_ "number of months in employment"  

* generate totals over months first
foreach var of varlist workh_c workh_a{
   bys ID_t month: egen `var'_1=total(`var')
   bys ID_t month: egen `var'_2=max(`var'), missing 
   replace `var'_1=`var'_2 if inlist(`var'_1,0,.) & `var'_2>.
   replace `var'_1=.e if `var'_1>=20 & `var'_1<.  & inlist(`var'_2,.a,.d)
   replace `var'_1=.f if `var'_1>=40 & `var'_1<.  & inlist(`var'_2,.a,.d)  
   lab val `var'_1 `var'  
   }
* generate mean per age
foreach var of varlist workh_c workh_a{
   bys ID_t agefy: egen `var'_3=mean(`var'_1)
   bys ID_t agefy: egen `var'_4=max(`var'_1), missing    
   replace `var'_3=`var'_4 if `var'_3==.
   replace `var'_3=.e if `var'_3<40 & `var'_4==.e
   replace `var'_3=.f if `var'_4==.f
   lab val `var'_3 `var'
   drop `var' `var'_1 `var'_2 `var'_4
   ren `var'_3 `var'_   
   }
drop temp*
lab var workh_c "average weekly working hours (contractual)" 
lab var workh_a "average weekly working hours (actual)" 
tab1 workh_c_ workh_a_, m // some cases with implausibly high working hours, most likely due to duplicates    


*** transfer into wide format

* indicator of youngest and oldest age when employment information are available
gen temp1=agefy if inlist(status,10,11,12,13)
bys ID_t: egen empage_min=min(temp1)
lab var empage_min "youngest age with employment information"
bys ID_t: egen empage_max=max(temp1)
lab var empage_max "oldest age with employment information"
drop temp1

* keep relevant observations, relevant variables and keep one row per month
keep if n==1 
keep if agefy>=10 // keep only information starting at age 10
keep ID_t empage_min empage_max agefy status_ egp_ profstatus_ isei_ pubserv_ fedwork_ emppara_ empmonths_ workh_c_ workh_a_

* reshape into wide format
reshape wide status_ egp_ isei_ profstatus_ pubserv_ fedwork_ emppara_ empmonths_ workh_c_ workh_a_, i(ID_t) j(agefy)
qui sum empage_max
local max=r(max)
foreach var of varlist egp_10- workh_a_`max'{
   replace `var'=.o if `var'==.
   }

* label variables
qui sum empage_max
local max=r(max)
foreach i of numlist 10/`max'{   
   lab var status_`i' "education/employment status age `i'"
   lab var egp_`i' "EGP class age `i'"
   lab var isei_`i' "ISEI-08 age `i'"   
   lab var profstatus_`i' "professional status age `i'"
   lab var pubserv_`i' "public service or private sector age `i'"
   lab var fedwork_`i' "federal state of work place age `i'"  
   lab var emppara_`i' "average number of parallel monthly employment spells age `i'" 
   lab var empmonths_`i' "number of months in employment age `i'"    
   lab var workh_c_`i' "average weekly working hours (contractual) age `i'" 
   lab var workh_a_`i' "average weekly working hours (actual) age `i'" 
   } 

* order variables
order ID_t empage_min empage_max status_* egp_* isei_* profstatus_* pubserv_* fedwork_* emppara_* empmonths_* workh_c_* workh_a_*
    

*** Save data ******************************************************************
compress
save "${savedta}\occupation_prep.dta", replace	
exit




