********************************************************************************
* Recode variables after imputation                                            *
*                                                                              *    
* Steffen Schindler, 15/06/2025                                                *
********************************************************************************


use "${savedta}\imputed_dataset_50.dta", clear


*** End of first education episode *********************************************

*** age last year in education (not in educ for two subsequent years) ***
gen educlast_age=.
egen temp_miss=rowmiss(status_educ_*) 
foreach num of numlist 15/39{ 
   local a=`num'-1
   local b=`num'+1
   replace educlast_age=`a' if status_educ_`num'==0 & status_educ_`b'==0 & educlast_age==.
   replace educlast_age=.z if status_educ_`num'==0 & status_educ_`b'==. & educlast_age==. // set to .z when unclear if 2 years out of education 
   replace educlast_age=.z if status_educ_`num'==. & status_educ_`b'==0 & educlast_age==. // set to .z when unclear if 2 years out of education 
   replace educlast_age=.z if status_educ_`num'==. & status_educ_`b'==. & educlast_age==. // set to .z when unclear if 2 years out of education   
   }
replace educlast_age=.a if educlast_age==. & temp_miss==0           // code .a if never out of education for 2 years if no missings on status_educ_*
gen temp1a=educlast_age if _mi_m==0 & temp_miss>0 & educlast_age<.z // only if _mi_m has valid values despite missings on status_educ_* 
bys ID_t: egen temp1b=max(temp1a)
replace educlast_age=temp1b if _mi_m!=0 & temp1b<.                  // double check: make sure that all values per case are the same if m=0 has no missings
replace educlast_age=. if educlast_age==.z                          // code missings in m=0 as .
lab def educlast .a "never left education for more than 2 years"
lab val educlast_age educlast  
lab var educlast_age "age final year of first education episode"
drop temp_miss temp1a temp1b
mi register passive educlast_age


*** Labor market variables *****************************************************

*** first significant job ***

* age first significant job
// criteria: in employment for more than 12 months, no parallel spells in education, >=20h working time per week
gen sigjob1_age=.
egen temp_miss=rowmiss(status_emp_*) 
foreach num of numlist 15/39{ 
   local a=`num'+1
   egen temp=rowtotal(empmonths_`num' empmonths_`a') 
   replace sigjob1_age=`num' if status_emp_`num'==1 & status_emp_`a'==1 & status_educ_`num'==0 ///
   & status_educ_`a'==0 & workh20_`num'==1 & workh20_`a'==1 & sigjob1_age==. & temp>12  
   replace sigjob1_age=.z if sigjob1_age==. & (status_emp_`num'==. | status_emp_`a'==.) // set to .z when unclear if significant job 
   drop temp
   }
replace sigjob1_age=.a if sigjob1_age==. & temp_miss==0
gen temp1a=sigjob1_age if _mi_m==0 & temp_miss>0 & sigjob1_age<.z // only if _mi_m has valid values despite missings on status_emp_* 
bys ID_t: egen temp1b=max(temp1a)
replace sigjob1_age=temp1b if _mi_m!=0 & temp1b<.                 // double check: make sure that all values per case are the same if m=0 has no missings
replace sigjob1_age=. if sigjob1_age==.z                          // code missings in m=0 as .
lab def sigjob .a "never had a significant job"
lab val sigjob1_age sigjob
lab var sigjob1_age "age first significant job"
drop temp_miss temp1a temp1b
mi register passive sigjob1_age

* ISEI first significant job
gen sigjob1_isei=.
foreach num of numlist 15/39{ 
   replace sigjob1_isei=isei_`num' if sigjob1_age==`num' & sigjob1_isei==.
   }
replace sigjob1_isei=.a if sigjob1_isei==. & sigjob1_age==.a
lab val sigjob1_isei sigjob
lab var sigjob1_isei "ISEI first significant job"
mi register passive sigjob1_isei

* Self-employed in first significant job
gen sigjob1_self=.
foreach num of numlist 15/39{ 
   replace sigjob1_self=selfemp_`num' if sigjob1_age==`num' & sigjob1_self==.
   }
replace sigjob1_self=.a if sigjob1_self==.  & sigjob1_age==.a
lab def selfemp .a "never had a significant job", modify 
lab val sigjob1_self selfemp
lab var sigjob1_self "self-employed in first significant job"
mi register passive sigjob1_self

* Public service in first significant job
gen sigjob1_pub=.
foreach num of numlist 15/39{ 
   replace sigjob1_pub=pubserv_`num' if sigjob1_age==`num' & sigjob1_pub==.
   }
replace sigjob1_pub=.a if sigjob1_pub==.  & sigjob1_age==.a
lab def pubserv .a "never had a significant job", modify 
lab val sigjob1_pub pubserv
lab var sigjob1_pub "public service in first significant job"
mi register passive sigjob1_pub

* East or West Germany in first significant job
gen sigjob1_east=.
foreach num of numlist 15/39{ 
   replace sigjob1_east=eastwest_`num' if sigjob1_age==`num' & sigjob1_east==.
   }
replace sigjob1_east=.a if sigjob1_east==. & sigjob1_age==.a
recode sigjob1_east (0=1) (1=0) 
lab def westeast 0 "west" 1 "east" .a "never had a significant job", modify 
lab val sigjob1_east westeast
lab var sigjob1_east "East or West Germany in first significant job"
mi register passive sigjob1_east


*** job at age 40 ***

* ISEI age 40
gen job40_isei=isei_40
replace job40_isei=.a if (job40_isei==0 | status_emp_40==0)
lab def job40 .a "not in employment"
lab val job40_isei job40
lab var job40_isei "ISEI job at age 40"
mi register passive job40_isei

* Self-employed at age 40
gen job40_self=selfemp_40
replace job40_self=.a if status_emp_40==0
lab def job40_self 0 "not self-employed" 1 "self-employed" .a "not in employment"
lab val job40_self job40_self
lab var job40_self "Self-employed at age 40"
mi register passive job40_self

* Public service job at age 40
gen job40_pub=pubserv_40
replace job40_pub=.a if status_emp_40==0
lab def job40_pub 0 "private sector" 1 "public sector" .a "not in employment"
lab val job40_pub job40_pub
lab var job40_pub "Public service at age 40"
mi register passive job40_pub

* Job in East or West Germany at age 40
gen job40_east=eastwest_40
replace job40_east=.a if status_emp_40==0
recode job40_east (0=1) (1=0)
lab def job40_east 0 "west" 1 "east" .a "not in employment"
lab val job40_east job40_east
lab var job40_east "Job in East or West Germany at age 40"
mi register passive job40_east


*** Duration in employment ***

* months in employment until age 40
egen temp_miss=rowmiss(empmonths_*) 
egen empmonths=rowtotal(empmonths_15-empmonths_40)
replace empmonths=. if _mi_m==0 & temp_miss>0   // set m=0 to missing if missings on empmonths_*) 
mi register passive empmonths


*** Earnings *******************************************************************

*** adjust information on working hours and employment status

* replace working hours 40 if they are zero but respondent is in employment and has earnings
gen temp1=1 if workhours_40==0 & status_emp_40==1 & ((net_earn_40>0 & net_earn_40<.) | (gross_earn_40>0 & gross_earn_40<.))
egen temp2=rowmean(workhours_39 workhours_41)
replace workhours_40=temp2 if workhours_40==0 & temp1==1 & temp2!=. // replace with average from years before and after
sum workhours_40 if workh20_40==0
local a=round(r(mean),1)
sum workhours_40 if workh20_40==1
local b=round(r(mean),1) 
replace workhours_40=`a' if workhours_40==0 & temp1==1 & workh20_40==0 // insert mean value based on workh20_40
replace workhours_40=`b' if workhours_40==0 & temp1==1 & workh20_40==1 // insert mean value based on workh20_40
drop temp*

* replace employment status at age 40 if no working hours and no earnings
gen temp=1 if workhours_40==0 & status_emp_40==1 & (net_earn_40==0 | gross_earn_40==0)
ta temp, m // no cases
replace status_emp_40=0 if temp==1 & status_emp_40==1
drop temp


*** inflation-adjust earnings to prices of 2020 ***

* generate inflation-adjusted variables for ages 38-42
foreach num of numlist 38 39 40 41 42{
   gen earnyear=birthyear+`num'
   foreach var of varlist gross_earn_`num' net_earn_`num' gross_bonus_`num'{
      gen `var'_i=`var'
	  replace `var'_i=`var'*1.150747986 if earnyear==2008
      replace `var'_i=`var'*1.146788991 if earnyear==2009
      replace `var'_i=`var'*1.13507378  if earnyear==2010
      replace `var'_i=`var'*1.111111111 if earnyear==2011
      replace `var'_i=`var'*1.090512541 if earnyear==2012
      replace `var'_i=`var'*1.074113856 if earnyear==2013
      replace `var'_i=`var'*1.063829787 if earnyear==2014
      replace `var'_i=`var'*1.058201058 if earnyear==2015
      replace `var'_i=`var'*1.052631579 if earnyear==2016
      replace `var'_i=`var'*1.037344398 if earnyear==2017
      replace `var'_i=`var'*1.019367992 if earnyear==2018
      replace `var'_i=`var'*1.005025126 if earnyear==2019
      replace `var'_i=`var'*1.0         if earnyear==2020
      replace `var'_i=`var'*0.969932105 if earnyear==2021
      replace `var'_i=`var'*0.907441016 if earnyear==2022
      replace `var'_i=`var'*0.856898029 if earnyear==2023
      }
   drop earnyear
   lab var gross_earn_`num'_i "gross monthly earnings age `num' (prices of 2020)"
   lab var net_earn_`num'_i "net monthly earnings age `num' (prices of 2020)"
   lab var gross_bonus_`num'_i "special payments age `num' (per month, prices of 2020)"
   }
//list ID_t gross_earn_38 gross_earn_39 gross_earn_40 gross_earn_41 gross_earn_42 gross_earn_38_i gross_earn_39_i gross_earn_40_i gross_earn_41_i gross_earn_42_i birthyear if _mi_m >0, sepby(ID_t) nol


*** generate hourly earnings (based on inflation-adjusted earnings) ***

* generate gross totals from monthly payments and bonus payments
gen gross_total_40_i=gross_earn_40_i+gross_bonus_40_i
lab var gross_total_40_i "total gross monthly earnings age 40 (prices of 2020)"
lab def earnings .a "not in employment"
replace gross_total_40_i=.a if status_emp_40==0  // not in employment 
lab val gross_total_40_i earnings
gen temp1a=1 if gross_total_40_i==.a & _mi_m==0  // make sure that m>0 does not vary if m=0 has value .a
bys ID_t: egen temp1b=max(temp1a)                //
replace gross_total_40_i=.a if temp1b==1         //
gen gross_total_40_lni=ln(gross_total_40_i)      // log of total gross monthly earnings 
lab var gross_total_40_lni "log-total gross monthly earnings age 40 (prices of 2020)"
lab val gross_total_40_lni earnings
drop temp1a temp1b
mi register passive gross_total_40_i gross_total_40_lni

* recode net earnings 
replace net_earn_40_i=.a if status_emp_40==0     // not in employment
lab val net_earn_40_i earnings
gen temp1a=1 if net_earn_40_i==.a & _mi_m==0     // make sure that m>0 does not vary if m=0 has value .a
bys ID_t: egen temp1b=max(temp1a)                //
replace net_earn_40_i=.a if temp1b==1            //
gen net_earn_40_lni=ln(net_earn_40_i)            // log of net monthly earnings 
lab var net_earn_40_lni "log-net monthly earnings age 40 (prices of 2020)"
lab val net_earn_40_lni earnings
drop temp1a temp1b
mi register passive net_earn_40_i net_earn_40_lni

* generate gross hourly earnings 
gen gross_total_40h_i=(gross_total_40_i/4.35)/workhours_40 // 4.35 weeks per month
lab var gross_total_40h_i "total gross hourly earnings age 40 (prices of 2020)"
replace gross_total_40h_i=.a if status_emp_40==0 // not in employment
lab val gross_total_40h_i earnings
gen temp1a=1 if gross_total_40h_i==.a & _mi_m==0 // make sure that m>0 does not vary if m=0 has value .a
bys ID_t: egen temp1b=max(temp1a)                //
replace gross_total_40h_i=.a if temp1b==1        //
sum gross_total_40h_i, det
gen gross_total_40h_lni=ln(gross_total_40h_i)    // log of total gross hourly earnings
lab var gross_total_40h_lni "log-total gross hourly earnings age 40 (prices of 2020)"
lab val gross_total_40h_lni earnings
drop temp1a temp1b
mi register passive gross_total_40h_i gross_total_40h_lni

* generate net hourly earnings 
gen net_earn_40h_i=(net_earn_40_i/4.35)/workhours_40
lab var net_earn_40h_i "total net hourly earnings age 40 (prices of 2020)"
replace net_earn_40h_i=.a if status_emp_40==0 // not in employment
lab val net_earn_40h_i earnings
gen temp1a=1 if net_earn_40h_i==.a & _mi_m==0 // make sure that m>0 does not vary if m=0 has value .a
bys ID_t: egen temp1b=max(temp1a)             //
replace net_earn_40h_i=.a if temp1b==1        //
sum net_earn_40h_i, det
gen net_earn_40h_lni=ln(net_earn_40h_i)       // log of net hourly earnings 
lab var net_earn_40h_lni "log-net hourly earnings age 40 (prices of 2020)"
lab val net_earn_40h_lni earnings
drop temp1a temp1b
mi register passive net_earn_40h_i net_earn_40h_lni


*** Education ******************************************************************

*** indicator of imputed values ***
/*
* schooldegree_1
gen temp=schooldegree_1 if _mi_m ==0
replace temp=-99 if temp==.
bys ID_t: egen schooldegree_1_orig=max(temp)
replace schooldegree_1_orig=.n if schooldegree_1_orig==-99
lab val schooldegree_1_orig schooldegree
gen sdf_imputed=0
replace sdf_imputed=1 if schooldegree_1_orig==99
drop temp

* vocdegree_1
gen temp=vocdegree_1 if _mi_m ==0
replace temp=-99 if temp==.
bys ID_t: egen vocdegree_1_orig=max(temp)
replace vocdegree_1_orig=.n if vocdegree_1_orig==-99
lab val vocdegree_1_orig vocdegree
gen vdf_imputed=0
replace vdf_imputed=1 if vocdegree_1_orig==99
drop temp

* schooldegree_15 - schooldegree_40 and vocdegree_15 - vocdegree_40
foreach num of numlist 15/40{
   gen temp_s=0
   replace temp_s=1 if schooldegree_`num'==. & _mi_m==0
   bys ID_t: egen sd`num'_imputed=max(temp_s)
   gen temp_v=0
   replace temp_v=1 if vocdegree_`num'==. & _mi_m==0
   bys ID_t: egen vd`num'_imputed=max(temp_v)
   drop temp_s temp_v
   }
*/
*** correct for implausible education degrees (carry forward approach) ***

* override if subsequent degree is lower than previous degree
foreach num of numlist 16/40{
   local m=`num'-1
   replace schooldegree_`num'=schooldegree_`m' if schooldegree_`num'<schooldegree_`m' & inrange(schooldegree_`m',0,6) & _mi_m>0
   replace vocdegree_`num'=vocdegree_`m' if vocdegree_`num'<vocdegree_`m' & inrange(vocdegree_`m',0,4) & _mi_m>0
   }
   
*** variables indicating school and vocational degrees at different time points ***

* first school and vocational degrees
gen schooldegree_1_new=0 
gen vocdegree_1_new=0
gen schooldegree_1_new_age=0 
gen vocdegree_1_new_age=0
foreach num of numlist 15/40{
   replace schooldegree_1_new=schooldegree_`num' if inrange(schooldegree_`num',1,6) & schooldegree_1_new==0
   replace schooldegree_1_new=. if schooldegree_`num'==. & schooldegree_1_new==0	
   replace schooldegree_1_new_age=`num' if inrange(schooldegree_`num',1,6) & schooldegree_1_new_age==0	
   replace schooldegree_1_new_age=. if schooldegree_`num'==. & schooldegree_1_new_age==0	
   replace vocdegree_1_new=vocdegree_`num' if inrange(vocdegree_`num',1,4) & vocdegree_1_new==0
   replace vocdegree_1_new=. if vocdegree_`num'==. & vocdegree_1_new==0	
   replace vocdegree_1_new_age=`num' if inrange(vocdegree_`num',1,4) & vocdegree_1_new_age==0	
   replace vocdegree_1_new_age=. if vocdegree_`num'==. & vocdegree_1_new_age==0   
   }
replace schooldegree_1_new_age=.a if schooldegree_1_new==0 
replace vocdegree_1_new_age=.a if vocdegree_1_new==0 
foreach var of varlist schooldegree_1_new schooldegree_1_new_age vocdegree_1_new vocdegree_1_new_age{
   gen temp1a=`var' if `var' !=. & _mi_m==0  // make sure that m>0 does not vary if m=0 has value .a
   bys ID_t: egen temp1b=max(temp1a)         //
   replace `var'=temp1b if temp1b!=.         //
   drop temp1a temp1b                        //
   }
lab var schooldegree_1_new "first school-leaving degree (generated after imputation)"
lab val schooldegree_1_new schooldegree
lab var vocdegree_1_new "first vocational degree (generated after imputation)"
lab val vocdegree_1_new vocdegree
lab def degree .a"no degree" .b"never had a significant job" 
lab var schooldegree_1_new_age "age first school-leaving degree"
lab val schooldegree_1_new_age degree
lab var vocdegree_1_new_age "age first vocational degree"
lab val vocdegree_1_new_age degree

* first school and vocational degrees before labor market entry
gen schooldegree_1_blm=0 
gen vocdegree_1_blm=0
gen schooldegree_1_blm_age=0 
gen vocdegree_1_blm_age=0
foreach num of numlist 15/40{
   replace schooldegree_1_blm=schooldegree_`num' if inrange(schooldegree_`num',1,6) & schooldegree_1_blm==0 & sigjob1_age>=`num'
   replace schooldegree_1_blm=. if (schooldegree_`num'==. & schooldegree_1_blm==0 & sigjob1_age>=`num') | sigjob1_age==.
   replace schooldegree_1_blm_age=`num' if inrange(schooldegree_`num',1,6) & schooldegree_1_blm_age==0 & sigjob1_age>=`num'	
   replace schooldegree_1_blm_age=. if (schooldegree_`num'==. & schooldegree_1_blm_age==0 & sigjob1_age>=`num') | sigjob1_age==.		   
   replace vocdegree_1_blm=vocdegree_`num' if inrange(vocdegree_`num',1,4) & vocdegree_1_blm==0 & sigjob1_age>=`num'
   replace vocdegree_1_blm=. if (vocdegree_`num'==. & vocdegree_1_blm==0 & sigjob1_age>=`num') | sigjob1_age==.	
   replace vocdegree_1_blm_age=`num' if inrange(vocdegree_`num',1,4) & vocdegree_1_blm_age==0 & sigjob1_age>=`num'	
   replace vocdegree_1_blm_age=. if (vocdegree_`num'==. & vocdegree_1_blm_age==0 & sigjob1_age>=`num') | sigjob1_age==.	   
   }
replace schooldegree_1_blm=.b if sigjob1_age==.a
replace vocdegree_1_blm=.b if sigjob1_age==.a
replace schooldegree_1_blm_age=.a if schooldegree_1_blm==0 
replace schooldegree_1_blm_age=.b if sigjob1_age==.a 
replace vocdegree_1_blm_age=.a if vocdegree_1_blm==0 
replace vocdegree_1_blm_age=.b if sigjob1_age==.a
foreach var of varlist schooldegree_1_blm schooldegree_1_blm_age vocdegree_1_blm vocdegree_1_blm_age{
   gen temp1a=`var' if `var' !=. & _mi_m==0  // make sure that m>0 does not vary if m=0 has value .a
   bys ID_t: egen temp1b=max(temp1a)         //
   replace `var'=temp1b if temp1b!=.         //
   drop temp1a temp1b                        //
   }
lab def schooldegree .b "never had a significant job", modify
lab def vocdegree .b "never had a significant job", modify
lab var schooldegree_1_blm "first school-leaving degree before labor market entry"
lab val schooldegree_1_blm schooldegree
lab var vocdegree_1_blm "first vocational degree before labor market entry"
lab val vocdegree_1_blm vocdegree
lab var schooldegree_1_blm_age "age first school-leaving degree before labor market entry"
lab val schooldegree_1_blm_age degree
lab var vocdegree_1_blm_age "age first vocational degree before labor market entry"
lab val vocdegree_1_blm_age degree

* compare variables generated before and after imputation (schooldegree_1 and vocdegree_1) 
tab schooldegree_1 schooldegree_1_new,m            
gen temp1=1 if schooldegree_1!=schooldegree_1_new 
tab temp1,m // 388 differences out of 147,543 (0.26%)
list ID_t _mi_m schooldegree_15-schooldegree_40 schooldegree_1 schooldegree_1_new if temp1==1, sepby(ID_t)
tab schooldegree_1 if _mi_m==0,m     //
tab schooldegree_1 if _mi_m!=0,m     // distribitions are very similar, we use schooldegree_1_new in further analyses
tab schooldegree_1_new if _mi_m!=0,m //
tab vocdegree_1 vocdegree_1_new,m            
gen temp2=1 if vocdegree_1!=vocdegree_1_new 
tab temp2,m // 6,082 differences out of 147,543 (4.12%)
tab vocdegree_1 vocdegree_1_new if temp2==1 & _mi_m!=0
tab vocdegree_1 if _mi_m==0,m     //
tab vocdegree_1 if _mi_m!=0,m     // distribitions are similar, we use vocdegree_1_new in further analyses
tab vocdegree_1_new if _mi_m!=0,m //
drop temp*

* plausibility checks
ta schooldegree_1_new_age schooldegree_1_new if _mi_m!=0,m // some cases with Abitur/FH-Reife below the age of 18
ta vocdegree_1_new_age vocdegree_1_new if _mi_m!=0,m       // some cases with Higher Education below the age of 20
list ID_t _mi_m schooldegree_1_new_age schooldegree_1_new vocdegree_1_new_age vocdegree_1_new if (schooldegree_1_new_age<18 & inlist(schooldegree_1_new,5,6)), sepby(ID_t)
// ---> leave all those cases in the sample, it could have been an input error regarding dates, no systematic bias expected
list ID_t _mi_m schooldegree_1_new_age schooldegree_1_new vocdegree_1_new_age vocdegree_1_new if (vocdegree_1_new_age<20 & inlist(vocdegree_1_new,3,4)), sepby(ID_t)
// --> inspect ID_t 8023059, 8019982 and 8023692
list ID_t _mi_m schooldegree_15-schooldegree_40 vocdegree_15-vocdegree_40 schooldegree_1_new_age schooldegree_1_new vocdegree_1_new_age vocdegree_1_new if ID_t==8023059
// --> imputation returns 3 implausible cases out of 50 --> leave case in sample
list ID_t _mi_m schooldegree_15-schooldegree_40 vocdegree_15-vocdegree_40 schooldegree_1_new_age schooldegree_1_new vocdegree_1_new_age vocdegree_1_new if ID_t==8019982
// --> imputation returns 4 implausible cases out of 50 --> leave case in sample
list ID_t _mi_m schooldegree_15-schooldegree_40 vocdegree_15-vocdegree_40 schooldegree_1_new_age schooldegree_1_new vocdegree_1_new_age vocdegree_1_new if ID_t==8023692
// --> non-imputed case, implausible --> exclude from sample
drop if ID_t==8023692


*** generate combined school and vocational degrees ***

* define label
lab def educdegree ///
10 "no voc - no school" ///
11 "no voc - spec.needs" ///
12 "no voc - Haupt" ///
13 "no voc - qual.Haupt" ///
14 "no voc - MR" ///
15 "no voc - FHR" ///
16 "no voc - Abitur" ///
20 "VOC1 - no school" ///
21 "VOC1 - spec.needs" ///
22 "VOC1 - Haupt" ///
23 "VOC1 - qual.Haupt" ///
24 "VOC1 - MR" ///
25 "VOC1 - FHR" ///
26 "VOC1 - Abitur" ///
30 "VOC2 - no school" ///
31 "VOC2 - spec.needs" ///
32 "VOC2 - Haupt" ///
33 "VOC2 - qual.Haupt" ///
34 "VOC2 - MR" ///
35 "VOC2 - FHR" ///
36 "VOC2 - Abitur" ///
40 "HE1 - no school" ///
41 "HE1 - spec.needs" ///
42 "HE1 - Haupt" ///
43 "HE1 - qual.Haupt" ///
44 "HE1 - MR" ///
45 "HE1 - FHR" ///
46 "HE1 - Abitur" ///
50 "HE2 - no school" ///
51 "HE2 - spec.needs" ///
52 "HE2 - Haupt" ///
53 "HE2 - qual.Haupt" ///
54 "HE2 - MR" ///
55 "HE2 - FHR" ///
56 "HE2 - Abitur" ///
.a "never left education for more than 2 years" ///
.b "never had a significant job"

* first combined degree
recode vocdegree_1_new (0=10) (1=20) (2=30) (3=40) (4=50), into(educdegree_1)
gen temp=.
forvalues i=15/40{
   replace temp=schooldegree_`i' if vocdegree_1_new_age==`i' 	
   }
replace temp=schooldegree_1_new if vocdegree_1_new_age==.a 
replace educdegree_1=educdegree_1+temp  
lab var educdegree_1 "first combined school and vocational degree"
lab val educdegree_1 educdegree
lab val temp schooldegree
ta educdegree_1 vocdegree_1_new,m
ta educdegree_1 temp,m
drop temp

* first combined degree before labor market entry
recode vocdegree_1_blm (0=10) (1=20) (2=30) (3=40) (4=50), into(educdegree_1_blm)
gen temp=.
forvalues i=15/40{
   replace temp=schooldegree_`i' if vocdegree_1_blm_age==`i' 	
   }
replace temp=schooldegree_1_blm if vocdegree_1_blm==0
replace educdegree_1_blm=educdegree_1_blm+temp  
replace educdegree_1_blm=.b if vocdegree_1_blm==.b 
lab var educdegree_1_blm "first combined school and vocational degree before labor market entry"
lab val educdegree_1_blm educdegree
ta educdegree_1_blm vocdegree_1_blm,m
ta educdegree_1_blm temp,m
drop temp

* combined degree at the end of the first education episode
gen temp_school=.
gen temp_voc=.
forvalues i=15/40{
   local k=`i'-1 	
   replace temp_school=schooldegree_`i' if educlast_age==`k' & temp_school==.
   replace temp_voc=vocdegree_`i' if educlast_age==`k' & temp_voc==. 
   }
gen educdegree_end1=(temp_voc*10)+10+temp_school
replace educdegree_end1=.a if educlast_age==.a
lab var educdegree_end1 "combined school and vocational degree at the end of first education episode"
lab val educdegree_end1 educdegree
ta educdegree_end1 temp_voc,m
ta educdegree_end1 temp_school,m 
drop temp* 

* combined degree at labor market entry
gen temp_school=.
gen temp_voc=.
forvalues i=15/40{
   replace temp_school=schooldegree_`i' if sigjob1_age==`i' & temp_school==.
   replace temp_voc=vocdegree_`i' if sigjob1_age==`i' & temp_voc==. 
   }
gen educdegree_lme=(temp_voc*10)+10+temp_school
replace educdegree_lme=.b if sigjob1_age==.a
lab var educdegree_lme "combined school and vocational degree at labor market entry"
lab val educdegree_lme educdegree
lab val temp_school schooldegree
lab val temp_voc vocdegree
ta educdegree_lme temp_voc,m
ta educdegree_lme temp_school,m 
drop temp*

* combined degree at age 40
recode vocdegree_40 (0=10) (1=20) (2=30) (3=40) (4=50), into(educdegree_40)
replace educdegree_40=educdegree_40+schooldegree_40 	
lab var educdegree_40 "combined school and vocational degree age 40"
lab val educdegree_40 educdegree
ta educdegree_40 vocdegree_40,m
ta educdegree_40 schooldegree_40,m


*** Ability-Proxiy ***

* ability-grouping based on GPA of first school-leaving degree
// based on procedure by Traini, C., Kleinert, C. and Schindler, S. (2021):
// Does tracking really affect labour-market outcomes in the long run? 
// Estimating the long-term effects of secondary-school tracking in West Germany. 
// Longitudinal and Life Course Studies, 12(3), 389-422.
// DOI: 10.1332/175795920X16062248132253
gen ability=. 
lab var ability "proxi for ability group"
// No degree
replace ability=8 if schooldegree_1_gpa==0 // 2 cases from Haupt/Mittl.Reife in schooldegree_1_gpa==0! set to 8 anyways!
// Special needs schools, Hauptschule and qual. Hauptschule
replace ability=2 if inrange(schooldegree_1_gpa,0.8,1.4) & inlist(schooldegree_1_new,1,2,3)
replace ability=3 if inrange(schooldegree_1_gpa,1.4,2.0) & inlist(schooldegree_1_new,1,2,3)
replace ability=4 if inrange(schooldegree_1_gpa,2.0,2.3) & inlist(schooldegree_1_new,1,2,3)
replace ability=5 if inrange(schooldegree_1_gpa,2.4,3.0) & inlist(schooldegree_1_new,1,2,3)
replace ability=6 if inrange(schooldegree_1_gpa,3.0,3.3) & inlist(schooldegree_1_new,1,2,3)
replace ability=7 if inrange(schooldegree_1_gpa,3.3,4.0) & inlist(schooldegree_1_new,1,2,3)
replace ability=8 if inrange(schooldegree_1_gpa,4.0,5.0) & inlist(schooldegree_1_new,1,2,3)
// Mittlere Reife
replace ability=1 if inrange(schooldegree_1_gpa,0.8,1.3) & inlist(schooldegree_1_new,4)
replace ability=2 if inrange(schooldegree_1_gpa,1.3,1.8) & inlist(schooldegree_1_new,4)
replace ability=3 if inrange(schooldegree_1_gpa,1.8,2.4) & inlist(schooldegree_1_new,4)
replace ability=4 if inrange(schooldegree_1_gpa,2.4,2.9) & inlist(schooldegree_1_new,4)
replace ability=5 if inrange(schooldegree_1_gpa,2.9,3.3) & inlist(schooldegree_1_new,4)
replace ability=6 if inrange(schooldegree_1_gpa,3.3,3.8) & inlist(schooldegree_1_new,4)
replace ability=7 if inrange(schooldegree_1_gpa,3.8,5.0) & inlist(schooldegree_1_new,4)
// Fachhochschulreife and Abitur
replace ability=1 if inrange(schooldegree_1_gpa,0.8,1.7) & inlist(schooldegree_1_new,5,6)
replace ability=2 if inrange(schooldegree_1_gpa,1.7,2.2) & inlist(schooldegree_1_new,5,6)
replace ability=3 if inrange(schooldegree_1_gpa,2.2,3.0) & inlist(schooldegree_1_new,5,6)
replace ability=4 if inrange(schooldegree_1_gpa,3.0,3.4) & inlist(schooldegree_1_new,5,6)
replace ability=5 if inrange(schooldegree_1_gpa,3.4,4.0) & inlist(schooldegree_1_new,5,6)
replace ability=6 if inrange(schooldegree_1_gpa,4.0,4.8) & inlist(schooldegree_1_new,5,6)
replace ability=7 if inrange(schooldegree_1_gpa,4.8,5.0) & inlist(schooldegree_1_new,5,6)


*** register education variables ***
// vocdegree_15-vocdegree_40 will be altered through mi update and should not be used for subsequent analyses
mi register passive schooldegree_1_new schooldegree_1_new_age vocdegree_1_new vocdegree_1_new_age
mi register passive schooldegree_1_blm schooldegree_1_blm_age vocdegree_1_blm vocdegree_1_blm_age 
mi register passive educdegree_1 educdegree_1_blm educdegree_end1 educdegree_lme educdegree_40
mi register passive ability


*** Weights ********************************************************************

* merge W2 sample weights
merge m:1 ID_t using "${data}\SC6_Weights_D_${SUF}.dta", nogen keep(1 3) keepusing(sample w_t2_cal w_t4_cal) 


*** Save data ******************************************************************
mi update
compress
save "${savedta}\recoded_imp40.dta", replace	
exit  
   
   
   
   
   
