********************************************************************************
* School basics plausibility checks and corrections                            *
*                                                                              *    
* Steffen Schindler, 15/06/2025                                                *
********************************************************************************

clear
set more off
cap log close

version 16.1

use "${savedta}\school_basics.dta"

*** PREPARATION ****************************************************************

* create new indicator of parallel month spells (only school spells)
bys ID_t month (splink schooldegree): gen monthnr_school=_n 
* sort date and create spell number
bys ID_t (month monthnr_school): gen n=_n
* assign shorter labels
lab def schooltype_s 1"Element/Volks" 2"Haupt/Real/POS" 3"Gesamt" 4"Waldorf" 5"Gymnasium" 6"Voc School" 7"Special needs" 8"other" .a"indeterminate", replace
lab val schooltype schooltype_s
lab def schooldegree_s 1"Haupt" 2"qual.Haupt" 3"Mittl. Reife" 4"FH-Reife" 5"Abitur" 6"Special needs" 7"other" ///
                    .a"indeterminate" .w"still attending school" .x"no qual. intended" .y"no qualification", replace
lab val schooldegree schooldegree_s
* create indicators for start and end of spell/date
bys ID_t splink: egen start=min(month)
lab var start "start of spell (months since 01/1960)"
bys ID_t splink: egen end=max(month)
lab var end "end of spell (months since 01/1960)"


*** PARALLEL SCHOOL SPELLS *****************************************************

* inspect and clean case-wise
bys ID_t: egen temp1=max(monthnr_school)
ta temp1 if n==1 // 240 cases with 2 parallel spells, 5 cases with 3 parallel spells
gen temp_mo=month
gen temp_ind=1 if monthnr_school>1
//list ID_t splink schooltype schooldegree month temp_mo monthnr_school temp_ind dur agey schoolgpa fedschool if temp1>1, sepby(ID_t)
drop if ID_t==8000424 & splink==220002 & month<=246 // age not plausible 
drop if ID_t==8000438 & splink==220002              // duplicate 
drop if ID_t==8000527 & splink==220003              // duplicate and implausible age
drop if ID_t==8000530                               // implausible sequence of school types --> drop complete case
drop if ID_t==8000612 & splink==220004              // duplicate
drop if ID_t==8000658 & splink==220003 & month<=-22 // age not plausible 
drop if ID_t==8000658 & splink==220002              // age not plausible 
drop if ID_t==8000743 & splink==220002 & month<=-56 // overlap not plausible 
drop if ID_t==8000963 & splink==220002 & month<=75  // overlap not plausible 
drop if ID_t==8001030 & splink==220002 & month<=-57 // age not plausible 
drop if ID_t==8001030 & splink==220001              // duplicate 
drop if ID_t==8001075 & splink==220003 & month<=98  // overlap not plausible 
drop if ID_t==8001132 & splink==220003 & month<=-4  // overlap not plausible 
drop if ID_t==8001138 & splink==220002 & month<=450 // overlap not plausible 
drop if ID_t==8001138 & splink==220003 & month<=511 // overlap not plausible 
drop if ID_t==8001147 & splink==220003              // parallel school type contains no necessary information
drop if ID_t==8001162 & splink==220002 & month<=222 // overlap not plausible 
drop if ID_t==8001162 & splink==220003 & month<=294 // overlap not plausible
drop if ID_t==8001201 & splink==220002 & month<=138 // overlap not plausible
drop if ID_t==8001201 & splink==220003 & month<=174 // overlap not plausible
drop if ID_t==8001214 & splink==220003              // parallel school type contains no necessary information
drop if ID_t==8001280 & splink==220004              // implausible spell
drop if ID_t==8001281 & splink==220003 & month<=222 // overlap not plausible
drop if ID_t==8001354 & splink==220001              // duplicate
drop if ID_t==8001354 & splink==220002              // duplicate
drop if ID_t==8001354 & splink==220003              // duplicate
drop if ID_t==8001354 & splink==220004              // duplicate
drop if ID_t==8001518 & splink==220003              // duplicate
drop if ID_t==8001530 & splink==220002 & month<=159 // overlap not plausible
drop if ID_t==8001695 & splink==220002 & month<=199 // overlap not plausible
drop if ID_t==8001722 & splink==220005              // duplicate
drop if ID_t==8001732 & splink==220002 & month<=414 // overlap not plausible
drop if ID_t==8001756 & splink==220003 & month<=138 // overlap not plausible
drop if ID_t==8001756 & splink==220004 & month<=150 // overlap not plausible
drop if ID_t==8001812 & splink==220004              // duplicate
drop if ID_t==8001828 & splink==220002              // parallel school type contains no necessary information
drop if ID_t==8001886 & splink==220002 & month<=222 // overlap not plausible
drop if ID_t==8001914 & splink==220003 & month<=150 // overlap not plausible
drop if ID_t==8001941 & splink==220003 & month<=376 // overlap not plausible
drop if ID_t==8001960 & splink==220003              // age not plausible
drop if ID_t==8002022 & splink==220002 & month<=283 // overlap not plausible
drop if ID_t==8002065 & splink==220002 & month<=91  // overlap not plausible
drop if ID_t==8002132                               // implausible sequence of school types --> drop complete case
drop if ID_t==8002139 & splink==220002 & month<=173 // overlap not plausible
drop if ID_t==8002176 & splink==220003 & month>=176 // parallel school type contains no necessary information
drop if ID_t==8002187 & splink==220003              // parallel school type contains no necessary information
drop if ID_t==8002319 & splink==220002              // duplicate
drop if ID_t==8002424 & splink==220004 & month<=258 // overlap not plausible
drop if ID_t==8002458 & splink==220002 & month>=462 // overlap not plausible
drop if ID_t==8002507 & splink==220003 & month<=259 // overlap not plausible
drop if ID_t==8002535 & splink==220002              // parallel school type not plausible
drop if ID_t==8002539 & splink==220002 & month<=259 // overlap not plausible
drop if ID_t==8002578 & splink==220003              // parallel school type not plausible
drop if ID_t==8002641 & splink==220003 & month<=223 // overlap not plausible
drop if ID_t==8002703 & splink==220002 & month<=104 // overlap not plausible
drop if ID_t==8002727 & splink==220002 & month<=186 // overlap not plausible
drop if ID_t==8002843 & splink==220003              // parallel school type not plausible
drop if ID_t==8002867 & splink==220001              // parallel school type not plausible
drop if ID_t==8002905 & splink==220002 & month<=114 // overlap not plausible
drop if ID_t==8002945 & splink==220005              // duplicate
drop if ID_t==8002945 & splink==220006 & month<=114 // overlap not plausible
drop if ID_t==8002945 & splink==220003              // duplicate
drop if ID_t==8002960 & splink==220002 & month<=78  // overlap not plausible
drop if ID_t==8003096 & splink==220002 & month<=212 // overlap not plausible
drop if ID_t==8003191 & splink==220002 & month<=140 // overlap not plausible
drop if ID_t==8004323 & splink==220002 & month<=186 // overlap not plausible
drop if ID_t==8004328 & splink==220002 & month<=186 // overlap not plausible
drop if ID_t==8004357 & splink==220002              // parallel school type not plausible
drop if ID_t==8004357 & splink==220003 & month<=115 // overlap not plausible
drop if ID_t==8004357 & splink==220004              // parallel school type not plausible
drop if ID_t==8004522 & splink==220002              // duplicate
drop if ID_t==8004522 & splink==220005              // duplicate
drop if ID_t==8004535 & splink==220002 & month<=173 // overlap not plausible
drop if ID_t==8004598 & splink==220002 & month<=222 // overlap not plausible
drop if ID_t==8004685 & splink==220002 & month<=188 // overlap not plausible
drop if ID_t==8004750 & splink==220003              // parallel school type contains no necessary information
drop if ID_t==8004761 & splink==220002 & month<=197 // overlap not plausible
drop if ID_t==8004811 & splink==220003              // duplicate
drop if ID_t==8004828 & splink==220002 & month<=222 // overlap not plausible
drop if ID_t==8004828 & splink==220003 & month<=246 // overlap not plausible
drop if ID_t==8005111 & splink==220003 & month<=306 // overlap not plausible
drop if ID_t==8005111 & splink==220002              // duplicate
drop if ID_t==8005126 & splink==220002 & month<=105 // overlap not plausible
drop if ID_t==8005256 & splink==220002 & month<=222 // overlap not plausible
drop if ID_t==8005307 & splink==220003              // duplicate
drop if ID_t==8005395 & splink==220002 & month<=378 // overlap not plausible
drop if ID_t==8005398 & splink==220002              // duplicate
drop if ID_t==8005398 & splink==220001 & month>=342 // overlap not plausible
drop if ID_t==8005441 & splink==220004              // duplicate
drop if ID_t==8005445 & splink==220002 & month<=211 // overlap not plausible
drop if ID_t==8005481 & splink==220003 & month<=510 // overlap not plausible
drop if ID_t==8005485 & inlist(splink,220003,220004) // "other" most likely no school spells
drop if ID_t==8005559 & splink==220003              // duplicate
drop if ID_t==8005575                               // mix-up of dates, not possible to reconstruct sequences --> drop complete case
drop if ID_t==8005679 & splink==220001 & month>=162 // overlap not plausible
drop if ID_t==8005746 & splink==220002 & month<=90  // overlap not plausible
drop if ID_t==8005897 & splink==220004 & month<=340 // parallel spell contains no necessary information
drop if ID_t==8006266 & splink==220002 & month<=234 // overlap not plausible
drop if ID_t==8006394 & splink==220002              // duplicate
drop if ID_t==8006394 & splink==220003 & month<=210 // overlap not plausible
drop if ID_t==8006524 & splink==220002 & month<=102 // overlap not plausible
drop if ID_t==8006616 & splink==220004              // parallel spell contains no necessary information
drop if ID_t==8006636 & splink==220003 & month<=176 // overlap not plausible
drop if ID_t==8006761 & splink==220002 & month<=126 // overlap not plausible
drop if ID_t==8006793 & splink==220005              // duplicate
drop if ID_t==8006834 & splink==220002 & month<=222 // overlap not plausible
drop if ID_t==8006940 & splink==220002              // parallel spell contains no necessary information
drop if ID_t==8007037 & splink==220004 & month<=403 // overlap not plausible
drop if ID_t==8007067 & splink==220001 & month>=92  // overlap not plausible
drop if ID_t==8007078 & splink==220003              // duplicate
replace schoolgpa=3.10 if ID_t==8007078 & splink==220002 // average of retained (3.0) and deleted (3.2) spell
drop if ID_t==8007122 & splink==220002 & month<=-13 // overlap not plausible
drop if ID_t==8007133 & splink==220003              // duplicate
drop if ID_t==8007275 & splink==220002              // duplicate
drop if ID_t==8007295 & splink==220003              // duplicate
drop if ID_t==8007454 & splink==220003              // parallel school type contains no necessary information
drop if ID_t==8007454 & splink==220004 & month>=105 // parallel school type contains no necessary information
drop if ID_t==8007544 & splink==220003              // parallel spell with implausible degree type
replace schooldegree=.y if ID_t==8007544 & splink==220006 // implausible to attain Abitur within 10 months (next spell ends with Abitur too)
replace schoolgpa=.m if ID_t==8007544 & splink==220006    // see previous line, set gpa to missing  
drop if ID_t==8007583 & splink==220006              // parallel spell contains no necessary information
drop if ID_t==8007591 & splink==220003              // parallel spell contains no necessary information
drop if ID_t==8007842 & splink==220001              // duplicate
drop if ID_t==8008033 & splink==220002              // parallel spell contains no necessary information
drop if ID_t==8008040 & splink==220005              // duplicate
drop if ID_t==8008301 & splink==220003 & month>=104 // overlap not plausible
drop if ID_t==8008544 & splink==220001 & month>=-18 // overlap not plausible
replace schooldegree=.x if ID_t==8008544 & splink==220001 // implausible value
replace schoolgpa=.m if ID_t==8008544 & splink==220001    // see previous line, set gpa to missing  
drop if ID_t==8008550 & splink==220003 & month<=-57 // overlap not plausible
drop if ID_t==8008588 & splink==220003              // duplicate
replace schooldegree=7 if ID_t==8008588 & splink==220004 // take over value from deleted parallel spell
drop if ID_t==8008683 & splink==220003              // parallel spell contains no necessary information
drop if ID_t==8008768 & splink==220001              // duplicate
drop if ID_t==8008775 & splink==220003              // duplicate
drop if ID_t==8008831 & splink==220004              // duplicate
drop if ID_t==8008911 & splink==220002              // parallel spell contains no necessary information
drop if ID_t==8008983 & splink==220002              // parallel spell contains no necessary information
drop if ID_t==8009034 & splink==220004              // parallel spell contains no necessary information
drop if ID_t==8009071 & splink==220002              // duplicate
drop if ID_t==8009071 & splink==220003 & month<=415 // overlap not plausible
drop if ID_t==8009150 & splink==220003 & month<=223 // overlap not plausible
drop if ID_t==8009198 & splink==220002              // implausible spell
drop if ID_t==8009198 & splink==220003 & month<=198 // overlap not plausible
drop if ID_t==8009224 & splink==220002              // duplicate
drop if ID_t==8009224 & splink==220004              // duplicate
drop if ID_t==8009284 & splink==220003 & month<=388 // overlap not plausible
drop if ID_t==8009300 & splink==220003              // duplicate
drop if ID_t==8009346 & splink==220003              // duplicate
drop if ID_t==8009488 & splink==220002 & month<=451 // overlap not plausible
drop if ID_t==8009510 & splink==220001              // implausible spell
drop if ID_t==8009588 & splink==220002              // most likely mix-up of dates, least in invasive to drop overlap 
drop if ID_t==8009593 & splink==220004              // implausible spell
drop if ID_t==8009609 & splink==220001 & month>=69  // overlap not plausible
drop if ID_t==8009714 & splink==220005              // parallel spell contains no necessary information
drop if ID_t==8009714 & splink==220004              // implausible spell
drop if ID_t==8009864 & splink==220001              // implausible sequence of school types, spell contains no necessary information
drop if ID_t==8009869 & splink==220001              // parallel spell contains no necessary information
drop if ID_t==8009927 & splink==220002              // overlap not plausible
drop if ID_t==8009961 & splink==220001 & month>=80  // overlap not plausible
drop if ID_t==8010007 & splink==220002 & month<=270 // overlap not plausible
drop if ID_t==8010007 & splink==220003 & month<=330 // overlap not plausible
drop if ID_t==8010011 & splink==220002 & month>=177 // overlap not plausible
replace month=month-72 if ID_t==8010120 & splink==220002    // date appears systematically wrong
replace agem=agem-72 if ID_t==8010120 & splink==220002      // date appears systematically wrong
replace agey=agey-(72/12) if ID_t==8010120 & splink==220002 // date appears systematically wrong
drop if ID_t==8010205 & splink==220001              // duplicate
drop if ID_t==8010228 & splink==220001 & month>=366 // overlap not plausible
drop if ID_t==8010330 & splink==220003              // parallel spell contains no necessary information
drop if ID_t==8010357 & splink==220002              // parallel spell contains no necessary information
drop if ID_t==8010405 & splink==220003              // parallel spell contains no necessary information
drop if ID_t==8010428 & splink==220004 & month<=563 // overlap not plausible
drop if ID_t==8010581 & splink==220001              // duplicate
drop if ID_t==8010582 & splink==220002              // duplicate
drop if ID_t==8010594 & splink==220004              // parallel spell contains no necessary information
replace month=month+47 if ID_t==8010714 & splink==220002       // ID 8010714: mix-up of dates 
replace temp_mo=temp_mo+47 if ID_t==8010714 & splink==220002   // ID 8010714: correct dates 
expand 13 if ID_t==8010714 & month==113, gen(temp)             // ID 8010714: expand according to data edition gap in biography data
sort ID_t month temp                                           // ID 8010714
replace month=month[_n-1]+1 if temp==1                         // ID 8010714: adjust month
replace temp_mo=month if temp==1                               // ID 8010714: adjust month
replace agem=month-birthdate if ID_t==8010714 & splink==220002 // ID 8010714: adjust age
replace agey=agem/12 if ID_t==8010714 & splink==220002         // ID 8010714: adjust age
drop temp                                                      // ID 8010714
drop if ID_t==8010923 & splink==220003              // parallel spell contains no necessary information
drop if ID_t==8010958 & splink==220002              // parallel spell contains no necessary information
drop if ID_t==8011093 & splink==220002 & month<=403 // overlap not plausible
drop if ID_t==8011136 & splink==220003 & month<=356 // overlap not plausible
drop if ID_t==8011152 & splink==220002 & month<=264 // overlap not plausible
drop if ID_t==8011245 & splink==220003 & month<=93  // overlap not plausible
drop if ID_t==8011304 & splink==220001 & month>=52  // overlap not plausible
drop if ID_t==8011304 & splink==220002 & month<=51  // overlap not plausible
drop if ID_t==8011403 & splink==220002 & month<=-16 // overlap not plausible
drop if ID_t==8011537 & splink==220002              // implausible spell
drop if ID_t==8011575 & splink==220002 & month<=117 // overlap not plausible
drop if ID_t==8011658 & splink==220002 & month<=237 // overlap not plausible
drop if ID_t==8011866 & splink==220002 & month<=90  // overlap not plausible, age at graduation remains implausible after correction 
drop if ID_t==8011917 & splink==220003              // duplicate
drop if ID_t==8011950 & splink==220004              // parallel spell contains no necessary information
replace schooltype=.a if ID_t==8011950 & splink==220001 // school type not plausible 
drop if ID_t==8011950 & splink==220002 & month>=429 // overlap not plausible
drop if ID_t==8011981 & splink==220001              // parallel spell contains no necessary information
drop if ID_t==8012033 & splink==220001 & month>=246 // overlap not plausible
drop if ID_t==8012118 & splink==220002 & month<=150 // overlap not plausible
drop if ID_t==8012132 & splink==220002 & month<=131 // overlap not plausible
drop if ID_t==8012169 & splink==220002              // duplicate
drop if ID_t==8012169 & splink==220003 & month<=222 // overlap not plausible
drop if ID_t==8012331 & splink==220003              // duplicate
drop if ID_t==8012377 & splink==220001 & month>=199 // overlap not plausible
drop if ID_t==8012409 & splink==220002 & month<=378 // overlap not plausible
drop if ID_t==8012559 & splink==220004              // duplicate
drop if ID_t==8012601 & splink==220002 & month<=162 // overlap not plausible
drop if ID_t==8012663 & splink==220003              // parallel spell contains no necessary information
drop if ID_t==8012679 & splink==220003              // parallel spell contains no necessary information
drop if ID_t==8012810 & splink==220004              // implausible spell
drop if ID_t==8012814 & splink==220003              // parallel spell contains no necessary information
drop if ID_t==8012846 & splink==220002              // parallel spell contains no necessary information
drop if ID_t==8014212 & splink==220001                     // ID 8014212 duplicate
drop if ID_t==8014212 & splink==220002                     // ID 8014212 duplicate
expand 2 if ID_t==8014212 & month==260  		           // ID 8014212 close gap created through drop
sort ID_t month monthnr                                    // ID 8014212
replace month=259 if ID_t==8014212 & month[_n-1]==258      // ID 8014212
replace agem=month-birthdate if ID_t==8014212 & month==259 // ID 8014212
replace agey=agem/12 if ID_t==8014212 & month==259         // ID 8014212
drop if ID_t==8014338 & splink==220001              // duplicate
drop if ID_t==8014338 & splink==220004              // parallel spell contains no necessary information
drop if ID_t==8014717 & splink==220002 & month<=199 // overlap not plausible
drop if ID_t==8014865 & splink==220003              // implausible spell
drop if ID_t==8019839 & splink==220002 & month<=127 // overlap not plausible
drop if ID_t==8019846 & splink==220001 & month>=139 // overlap not plausible
drop if ID_t==8020021 & splink==220002              // duplicate
drop if ID_t==8020298 & splink==220001 & month>=343 // overlap not plausible
drop if ID_t==8020581 & splink==220002 & month<=359 // parallel spell contains no necessary information
drop if ID_t==8020627 & splink==220001 & month>=84  // overlap not plausible
drop if ID_t==8020644 & splink==220003              // parallel spell contains no necessary information
drop if ID_t==8020666 & splink==220001 & month>=320 // overlap not plausible
drop if ID_t==8020757 & splink==220002              // parallel spell contains no necessary information
drop if ID_t==8020809 & splink==220001              // duplicate
drop if ID_t==8020817 & splink==220003 & month<=487      // ID 8020817 overlap/implausible sequence of school types
replace schooldegree=7 if ID_t==8020817 & splink==220003 // ID 8020817 degree abroad, change to 'other'
drop if ID_t==8020835 & splink==220002              // parallel spell contains no necessary information
drop if ID_t==8020963 & splink==220004 & month>=306 // overlap not plausible
drop if ID_t==8021005 & splink==220002 & month>=247 // overlap not plausible
drop if ID_t==8021189 & splink==220002 & month<=-9  // overlap not plausible
drop if ID_t==8021406 & splink==220002 & month<=-57 // overlap not plausible
drop if ID_t==8021486 & splink==220002 & month<=-7  // overlap not plausible
drop if ID_t==8021506 & splink==220001              // duplicate
drop if ID_t==8021506 & splink==220003 & month>=259 // overlap not plausible
drop if ID_t==8021523 & splink==220003              // implausible spell
drop if ID_t==8021523 & splink==220004              // duplicate
drop if ID_t==8021586 & splink==220002              // parallel spell contains no necessary information
drop if ID_t==8021713 & splink==220002 & month<=139 // overlap not plausible
drop if ID_t==8021755                               // implausible sequence of school types, not possible to reconstruct
drop if ID_t==8021889 & splink==220001 & month>=115 // overlap not plausible
drop if ID_t==8021889 & splink==220002 & month<=114 // overlap not plausible
drop if ID_t==8021967 & splink==220002              // parallel spell contains no necessary information
drop if ID_t==8022023 & splink==220004              // duplicate
drop if ID_t==8022113 & splink==220004              // parallel spell contains no necessary information
drop if ID_t==8022113 & splink==220005              // parallel spell contains no necessary information
drop if ID_t==8022259 & splink==220002              // implausible sequence of school types, parallel spell contains no plausible information
replace month=month+47 if ID_t==8022299 & splink==220002    // ID 8022299 date appears systematically wrong
replace agem=agem+47 if ID_t==8022299 & splink==220002      // ID 8022299 adjust age
replace agey=agey+(47/12) if ID_t==8022299 & splink==220002 // ID 8022299 adjust age
drop if ID_t==8022304 & splink==220004              // duplicate
drop if ID_t==8022444 & splink==220001 & month>=380 // overlap not plausible
drop if ID_t==8022445 & splink==220003              // overlap not plausible
replace schoolgpa=2.25 if ID_t==8022445 & splink==220002 // average of retained (2.5) and deleted (2.0) spell
drop if ID_t==8022449 & splink==220002 & month<=189 // overlap not plausible
drop if ID_t==8022498 & splink==220005              // implausible spell
drop if ID_t==8022537 & splink==220003              // duplicate
replace schoolgpa=3.15 if ID_t==8022537 & splink==220002 // average of retained (3.2) and deleted (3.1) spell
drop if ID_t==8022593 & splink==220002 & month<=381 // overlap not plausible
drop if ID_t==8022708 & splink==220001 & month>=415 // overlap not plausible
drop if ID_t==8022708 & splink==220003 & month<=475 // overlap not plausible
drop if ID_t==8022866 & splink==220003              // overlap not plausible
replace schoolgpa=2.50 if ID_t==8022866 & splink==220002 // average of retained (3.0) and deleted (2.0) spell
drop if ID_t==8022874 & splink==220002              // side spell contains no necessary information
drop if ID_t==8022902 & splink==220003              // duplicate
drop if ID_t==8022940 & splink==220002              // duplicate
drop if ID_t==8022948 & splink==220003              // duplicate
drop if ID_t==8022970 & splink==220003 & month<=273 // overlap not plausible
drop if ID_t==8023049 & splink==220005 & month>=555 // overlap not plausible
drop if ID_t==8023113 & splink==220005              // implausible parallel spell
drop if ID_t==8023135 & splink==220002 & month<=438 // overlap not plausible
drop if ID_t==8023230 & splink==220002 & month>=162 // overlap not plausible
drop if ID_t==8023310 & splink==220002              // duplicate
drop if ID_t==8023317 & splink==220001              // duplicate
drop if ID_t==8023402 & splink==220002              // duplicate
drop if ID_t==8023413 & splink==220002              // duplicate
drop if ID_t==8023504 & splink==220002 & month>=171 // overlap not plausible
drop if ID_t==8023657 & splink==220001              // duplicate
drop if ID_t==8023761 & splink==220003              // implausible parallel spell
drop if ID_t==8023851 & splink==220001              // duplicate
drop if ID_t==8023877 & splink==220002              // duplicate
drop if ID_t==8023877 & splink==220001 & month>=283 // overlap not plausible
drop if ID_t==8023950 & splink==220001 & month>=403 // overlap not plausible
drop if ID_t==8024010 & splink==220003 & month>=87  // overlap not plausible
drop if ID_t==8024170 & splink==220001 & month>=223 // overlap not plausible
drop if ID_t==8024326 & splink==220002 & month>=139 // overlap not plausible
drop if ID_t==8024326 & splink==220003 & month<=138 // overlap not plausible
drop if ID_t==8024366 & splink==220002              // parallel spell contains no necessary information
drop if ID_t==8024387 & splink==220003              // duplicate
drop if ID_t==8024492 & splink==220002 & month<=16  // overlap not plausible
drop if ID_t==8024823 & splink==220001 & month>=108 // overlap not plausible
drop if ID_t==8024833 & splink==220003              // parallel spell contains no necessary information
drop if ID_t==8024909 & splink==220004 & month<=581 // parallel spell contains no necessary information
drop if ID_t==8024949 & splink==220001 & month>=42  // overlap not plausible
drop if ID_t==8024966 & splink==220001 & month>=308 // overlap not plausible
drop if ID_t==8025040 & splink==220004              // parallel spell contains no necessary information
drop temp*


*** UPDATE OF INDICATORS ******************************************************* 

* update indicator of parallel month spells (only school spells)
drop monthnr_school
bys ID_t month (splink schooldegree): gen monthnr_school=_n 
bys ID_t: egen temp2=max(monthnr_school)
ta temp2 // no more cases with parallel spells
drop temp* monthnr_school

* check: any gaps within spells?
bys ID_t splink (month): gen temp1=_n
gen temp2=1 if ID_t==ID_t[_n-1] & splink==splink[_n-1] & (month-month[_n-1])>1 
ta temp2 // no gaps
drop temp* 

* update duration of spells
cap drop dur
bys ID_t splink (month): gen dur=_N

* update spell count per ID_t
cap drop n
bys ID_t (month): gen n=_n 

* age at start and end of spell
bys ID_t splink (month): egen startagem=min(agem)
bys ID_t splink (month): egen startagey=min(agey)
bys ID_t splink (month): egen endagem=max(agem)
bys ID_t splink (month): egen endagey=max(agey)


*** GRUND/VOLKSSCHULE **********************************************************

*** Grund-/Volksschule with indeterminate school leaving degrees
* tag cases and list
gen temp1=1 if schooltype==1 & schooldegree==.a
bys ID_t: egen temp2=max(temp1)
tab temp2 if n==1 // 9,846 cases with indeterminate information
* number of episodes in Grund-/Volksschule
egen temp_epiprim=group(ID_t splink) if schooltype==1
bys ID_t: egen temp3=min(temp_epiprim)
replace temp_epiprim=temp_epiprim-temp3+1
bys ID_t: egen temp_countprim=max(temp_epiprim)
tab temp_countprim if n==1,m // up to 6 episodes in Grund-/Volksschule
drop temp1 temp2 temp3

*** Summarize spells if more than one spell in Grund-/Volksschule
* generate auxiliary variables
bys ID_t schooltype (month): gen temp_n=_n if schooltype==1 // count Grund-/Volksschule spell 
gen temp1=month-month[_n-1] if ID_t==ID_t[_n-1] & temp_n!=. & splink!=splink[_n-1] 
bys ID_t splink: egen temp_gap=max(temp1) // gap to previous spell 
bys ID_t schooltype: egen temp_age=max(agey) if schooltype==1 // age in last Grund-/Volksschule spell 
bys ID_t schooltype: egen temp2=min(month) if schooltype==1 // date first Grund-/Volksschule spell
bys ID_t schooltype: egen temp3=max(month) if schooltype==1 // date last Grund-/Volksschule spell
gen temp_primdur=temp3-temp2 // months spent in Grund-/Volksschule
sort ID_t month
//list ID_t splink temp_n temp1 temp_gap temp_countprim temp2 temp3 temp_primdur month schooldegree agey startagey endagey temp_age if temp_age!=., sepby(ID_t)
drop temp1 temp2 temp3 

*** Grund-/Volksschule with implausible school leaving degrees
* tag implausible cases and list
gen temp1a=1 if schooltype==1 & inrange(schooldegree,3,5)
bys ID_t: egen temp1b=max(temp1a)
tab temp1b if n==1 // 136 cases with Mittlere Reife or Abitur obtained at Grund-/Volksschule
//list ID_t splink schooltype schooldegree schoolgpa month dur startagey endagey temp1a agey fedschool if temp1b==1, sepby(ID_t)
drop temp1*
* recode if schooltype appears wrong but schooldegree appears correct
replace schooltype=.a if schooltype==1 & inlist(schooldegree,4,5) & startagey>9 & endagey>17 // Fachhochschulreife/Abitur
replace schooltype=.a if schooltype==1 & schooldegree==3 & startagey>9 & endagey>15 // Mittlere Reife
* recode if there is any secondary-level schooltype with the same secondary-level school-leaaving degree --> set schooldegree=.x
forvalues i=1/5{ 
   gen temp1a=1 if schooltype==1 & schooldegree==`i' // Grund-/Volksschule with secondary-level degree
   bys ID_t: egen temp1b=max(temp1a)
   gen temp2a=1 if inrange(schooltype,2,8) & schooldegree==`i' // other school type with secondary-level degree
   bys ID_t: egen temp2b=max(temp2a)
   replace schoolgpa=.m if schooltype==1 & schooldegree==`i' & temp1b==1 & temp2b==1
   replace schooldegree=.x if schooltype==1 & schooldegree==`i' & temp1b==1 & temp2b==1 
   drop temp1* temp2*
   }
* recode if there is any lower-level schooldegree obtained later than the one in Grund-/Volksschule --> set schooldegree=.x
forvalues i=2/5{ 
   gen temp1a=endagem if schooltype==1 & schooldegree==`i' // age at end of Grund-/Volksschule spell with secondary-level degree
   bys ID_t: egen temp1b=max(temp1a)
   gen temp2a=endagem if inrange(schooltype,2,8) & schooldegree<`i' // age at end of other school type with lower-level degree
   bys ID_t: egen temp2b=max(temp2a)
   replace schoolgpa=.m if schooltype==1 & schooldegree==`i' & temp1b<temp2b & temp2b<.
   replace schooldegree=.x if schooltype==1 & schooldegree==`i' & temp1b<temp2b  & temp2b<.
   drop temp1* temp2*
   }
* recode if age at which degree has been obtained is too low --> set schooldegree=.a/.x
gen temp1a=1 if schooltype==1 & inlist(schooldegree,4,5) // Fachhochschulreife/Abitur
bys ID_t: egen temp1b=max(temp1a)  
tab temp1b if n==1 // 6 cases with Fachhochschulreife or Abitur obtained at Grund-/Volksschule
//list ID_t splink schooltype schooldegree startagey endagey schoolgpa month dur agey fedschool if temp1b==1, sepby(ID_t)
replace schoolgpa=.a if schooltype==1 & inlist(schooldegree,4,5) & endagey<17 & gerschool!=2 // cut-off 17 in Germany
replace schooldegree=.a if schooltype==1 & inlist(schooldegree,4,5) & endagey<17 & gerschool!=2 // --> .a indeterminate
replace schoolgpa=.m if schooltype==1 & inlist(schooldegree,4,5) & endagey<12 & gerschool!=2 // cut-off 12 in Germany
replace schooldegree=.x if schooltype==1 & inlist(schooldegree,4,5) & endagey<12 & gerschool!=2 // --> .x no qual. intended 
replace schoolgpa=.a if schooltype==1 & inlist(schooldegree,4,5) & endagey<16 & gerschool==2 // cut-off 16 abroad
replace schooldegree=.a if schooltype==1 & inlist(schooldegree,4,5) & endagey<16 & gerschool==2 // --> .a indeterminate
drop temp1*
gen temp1a=1 if schooltype==1 & schooldegree==3 // Mittlere Reife
bys ID_t: egen temp1b=max(temp1a)  
tab temp1b if n==1 // 46 cases with Mittlere Reife obtained at Grund-/Volksschule
//list ID_t splink schooltype schooldegree schoolgpa month dur startagey endagey temp1a agey fedschool if temp1b==1, sepby(ID_t)
replace schooldegree=.a if schooltype==1 & schooldegree==3 & schoolgpa>=. & gerschool!=2 & endagey<15 // cut-off 15 in Germany
replace schooldegree=.x if schooltype==1 & schooldegree==3 & schoolgpa>=. & gerschool!=2 & endagey<12 // cut-off 12 in Germany
drop temp1*
* recode if age at which degree appears correct, but Grund-/Volksschule seems implausible --> set schooltype=.a 
gen temp1a=1 if schooltype==1 & inlist(schooldegree,4,5) // Fachhochschulreife/Abitur
bys ID_t: egen temp1b=max(temp1a)  
tab temp1b if n==1 // 3 cases with Fachhochschulreife or Abitur obtained at Grund-/Volksschule
//list ID_t splink schooltype schooldegree startagey endagey schoolgpa month dur agey fedschool if temp1b==1, sepby(ID_t)
replace schooltype=.a if schooltype==1 & inlist(schooldegree,4,5) & endagey>=17 & gerschool!=2 // --> .a indeterminate (Germany) 
replace schooltype=.a if schooltype==1 & inlist(schooldegree,4,5) & endagey>=16 & gerschool==2 // --> .a indeterminate (abroad)  
replace schooltype=.a if schooltype==1 & inlist(schooldegree,4,5) & startagey>8 // --> .a indeterminate  
drop temp1*
gen temp1a=1 if schooltype==1 & schooldegree==3 // Mittlere Reife
bys ID_t: egen temp1b=max(temp1a)  
tab temp1b if n==1 // 44 cases with Mittlere Reife obtained at Grund-/Volksschule
//list ID_t splink schooltype schooldegree startagey endagey schoolgpa month dur agey fedschool if temp1b==1, sepby(ID_t)
replace schooltype=.a if schooltype==1 & schooldegree==3 & endagey>=15 & gerschool!=2 // --> .a indeterminate (Germany)  
replace schooltype=.a if schooltype==1 & schooldegree==3 & endagey>=14 & gerschool==2 // --> .a indeterminate (abroad) 
drop temp1* 
* check remaining cases: tag implausible cases and list
gen temp1a=1 if schooltype==1 & inrange(schooldegree,3,5)
bys ID_t: egen temp1b=max(temp1a)
tab temp1b if n==1 // 3 cases with Mittlere Reife or Abitur obtained at Grund-/Volksschule remaining
//list ID_t splink schooltype schooldegree schoolgpa month dur startagey endagey temp1a agey fedschool if temp1b==1, sepby(ID_t)
replace schooldegree=.x if ID_t==8000935 & splink==220001 // most likely mixup --> assign schooldegree/schoolgpa to spell 220002
replace schoolgpa=.y if ID_t==8000935 & splink==220001    // same case
replace schooldegree=3 if ID_t==8000935 & splink==220002  // same case
replace schoolgpa=2.80 if ID_t==8000935 & splink==220002  // same case
replace schoolgpa=.m if schooltype==1 & schooldegree==3 & endagey<15 & gerschool!=2 // --> .m missing by design (Germany)
replace schooldegree=.x if schooltype==1 & schooldegree==3 & endagey<15 & gerschool!=2 // --> .x no qual. intended (Germany)
replace schoolgpa=.a if schooltype==1 & schooldegree==3 & endagey<14 & gerschool==2 // --> .a indeterminate (abroad)
replace schooldegree=.a if schooltype==1 & schooldegree==3 & endagey<14 & gerschool==2 // --> .a indeterminate (abroad)
drop temp1*
   
*** Grund-/Volksschule with unknown degree
* multiple spells in Grund-/Volksschule
egen temp_spellno=group(ID_t splink) if schooltype==1
bys ID_t: egen temp1=min(temp_spellno) 
replace temp_spellno=temp_spellno-temp1+1
bys ID_t: egen temp_spells=max(temp_spellno)
tab temp_spells if n==1 // 1111 with 2; 66 with 3; 9 with 4; 1 with 6
* cumulative duration in Grund-/Hauptschule
bys ID_t schooltype (month): gen temp_durcum=_n if schooltype==1
bys ID_t: egen temp_dur=max(temp_durcum)
sort ID_t month
* marker: Grund-/Volksschule with unknown degree
gen temp1a=1 if schooltype==1 & schooldegree==.a
bys ID_t: egen temp1b=max(temp1a)
tab temp1b if n==1 // 9850 cases
//list ID_t splink schooltype schooldegree startagey endagey schoolgpa month temp_durcum temp_dur agey fedschool if temp1b==1, sepby(ID_t)
* marker: Hauptschulabschluss or qual. Hauptschulabschluss has been obtained in a different spell
gen temp2a=1 if inlist(schooldegree,1,2) 
bys ID_t: egen temp2b=max(temp2a)
* replace schooldegree with .x "no qual. intended" when duration at Grund-/Volksschule is so short that obtaining a degree is not possible 
replace schooldegree=.x if schooltype==1 & schooldegree==.a & temp_dur<=90 & end<=120 // until 1970 
replace schooldegree=.x if schooltype==1 & schooldegree==.a & temp_dur<=100 & end>120 // after 1970
* update: Grund-/Volksschule with unknown degree
drop temp1*
gen temp1a=1 if schooltype==1 & schooldegree==.a
bys ID_t: egen temp1b=max(temp1a)
tab temp1b if n==1 // 444 cases
* replace schooldegree with "no qual intended" when "Hauptschulabschluss" has been obtained in a different spell
replace schooldegree=.x if schooltype==1 & schooldegree==.a & temp2b==1
drop temp2*
* update: Grund-/Volksschule with unknown degree
drop temp1*
gen temp1a=1 if schooltype==1 & schooldegree==.a
bys ID_t: egen temp1b=max(temp1a)
tab temp1b if n==1 // 364 cases
* replace Grund-/Volksschule with unknown degree in GDR before 1959 --> set to schooldegree=Hauptschulabschluss if plausible
  // GDR before September 1959: 8-year primary school with school leaving degree (equivalent to Hauptschulabschluss)
  // Attention: this recode assumes that students have passed final exams (students who didn't pass might be misclassified)
gen temp_gdr1=1 if schooltype==1 & temp_dur==temp_durcum & inrange(fedschool,12,16) // indicator: last elementary school spell in GDR
bys ID_t splink: egen temp_gdr2=max(temp_gdr1)
bys ID_t: egen temp_gdr3=max(temp_gdr1)
gen temp2a=1 if temp_durcum==1 & month<-12 & inrange(temp_dur,90,108) // indicator: school start before reform (cut-off=01/1959) + cum. duration 7.5-9 years
bys ID_t: egen temp2b=max(temp2a)
replace schooldegree=1 if schooltype==1 & schooldegree==.a & temp_gdr2==1 & temp2b==1
replace schooldegree=.y if schooltype==1 & schooldegree==.a & temp_gdr3==1 & temp_gdr2==. & temp2b==1 & temp_spells>1 // recode to .y if previous spells in V/H
drop temp2*
* replace Grund-/Volksschule with unknown degree in GDR after 1959 --> set to schooldegree=Mittlere Reife if plausible
  // GDR as of September 1959: 10-year POS with school leaving degree (equivalent to Mittlere Reife)
  // Attention: this recode assumes that students have passed final exams (students who didn't pass might be misclassified)
gen temp2a=1 if temp_durcum==1 & inrange(month,-12,368) & temp_dur>=114 // indicator: school start after reform (cut-off=01/1959) + cum. duration >9.5 years
bys ID_t: egen temp2b=max(temp2a)
gen temp3a=1 if schooltype!=1 & schooldegree==3 // indicator: Mittlere Reife obtained in a different school spell
bys ID_t: egen temp3b=max(temp3a)
replace schooldegree=.x if schooltype==1 & schooldegree==.a & temp_gdr3==1 & temp2b==1 & temp3b==1 // recode to .y if MR obtainend in a different spell
replace schooldegree=3 if schooltype==1 & schooldegree==.a & temp_gdr2==1 & temp2b==1 & temp3b!=1 // recode to 3 otherwise
replace schooldegree=.y if schooltype==1 & schooldegree==.a & temp_gdr3==1 & temp_gdr2==. & temp2b==1 & temp_spells>1 // recode previous spells in V/H to .y
drop temp2* temp3*
* replace Grund-/Volksschule with unknown degree in GDR (1959-1983) and 4-year EOS --> set to schooldegree=.x no qual. intended
  // until 1983 students changed from grade 8 POS into EOS (without exam)
gen temp2a=1 if schooltype==1 & schooltype[_n+1]==5 & schooldegree==.a & schooldegree[_n+1]==5 & inrange(month,-12,284) & inrange(temp_dur,90,108) & inrange(dur[_n+1],42,60) & (inrange(fedschool,12,16) | inrange(fedschool,12,16)) // Grundschule not more than 9 years (8+1 potential retention), Gymnasium/EOS 4 years (+1 potential retention)  
bys ID_t splink: egen temp2b=max(temp2a)
bys ID_t (month): egen temp2c=max(temp2a)
replace schooldegree=.x if schooltype==1 & schooldegree==.a & temp2b==1
drop temp2*
* replace Grund-/Volksschule with unknown degree in FRG before 1970 --> set to schooldegree=Hauptschulabschluss if plausible
  // until 1968/1970 (month<=120) Volksschulabschluss was awarded with completion (no exam) of grade 8 (duration>90 months)
gen temp_frg1=1 if schooltype==1 & temp_dur==temp_durcum & inrange(fedschool,1,11) // indicator: last elementary school spell in FRG
bys ID_t splink: egen temp_frg2=max(temp_frg1)
bys ID_t: egen temp_frg3=max(temp_frg1)
gen temp2a=1 if schooltype==1 & temp_dur==temp_durcum & month<=120 & temp_dur>90 // indicator: end of school spell before reform + cum. duration >90 months 
bys ID_t: egen temp2b=max(temp2a)
replace schooldegree=1 if schooltype==1 & schooldegree==.a & temp_frg2==1 & temp2b==1
replace schooldegree=.y if schooltype==1 & schooldegree==.a & temp_frg3==1 & temp_frg2==. & temp2b==1 & temp_spells>1 // recode to .y if previous spells in G/V
drop temp2*
* replace Grund-/Volksschule with unknown degree in FRG after 1970 --> set to schooldegree=Hauptschulabschluss if plausible
  // 1970-1982 (120<month<264) Volksschulabschluss was awarded with completion (no exam) of grade 9 (duration>102 months)
gen temp2a=1 if schooltype==1 & temp_dur==temp_durcum & inrange(month,121,263) & temp_dur>102 // indicator: spell ends after reform + cum. duration >100 months 
bys ID_t: egen temp2b=max(temp2a)
replace schooldegree=1 if schooltype==1 & schooldegree==.a & temp_frg2==1 & temp2b==1
replace schooldegree=.y if schooltype==1 & schooldegree==.a & temp_frg3==1 & temp_frg2==. & temp2b==1 & temp_spells>1 // recode to .y if previous spells in G/V  
drop temp2*  
* replace first spell of Grund-/Volksschule with unknown degree in FRG after 1982 --> set schooldegree=.x "no qual. intended" if plausible
bys ID_t splink: egen temp2a=max(temp_durcum) if schooltype==1
gen temp2b=1 if schooltype==1 & schooldegree==.a & temp2a<=72 & month>=264 & inrange(fedschool,1,11) // first G/V spell duration <6 years, cut-off: 01/1982
bys ID_t splink: egen temp2c=max(temp2b)  
replace schooldegree=.x if temp2c==1
sort ID_t month
drop temp2*
* replace schooldegree with .y "no qual" if cumulative duration of spell is too short (<=7.5 years) to obtain a qualification 
bys ID_t splink: egen temp2a=max(temp_durcum) if schooltype==1
replace schooldegree=.y if schooltype==1 & schooldegree==.a & temp2a<=90 
drop temp2*
* update: Grund-/Volksschule with unknown degree
drop temp1*
gen temp1a=1 if schooltype==1 & schooldegree==.a
bys ID_t: egen temp1b=max(temp1a)
tab temp1b if n==1 // 39 cases
* recode case-wise
//list ID_t splink schooltype schooldegree startagey endagey schoolgpa month temp_durcum temp_dur dur agey end fedschool if temp1b==1, sepby(ID_t)
replace schooldegree=.y if ID_t==8007067 & splink==220001 // GDR, most likely no qualification
replace schooldegree=3 if ID_t==8007223 & splink==220001 // GDR, most likely MR (misclassified of person did not pass exam)
replace schooldegree=3 if ID_t==8007446 & splink==220001 // GDR, most likely MR (misclassified of person did not pass exam)
replace schooldegree=3 if ID_t==8011421 & splink==220001 // GDR, most likely MR (misclassified of person did not pass exam)
replace schooldegree=.y if ID_t==8020066 & splink==220001 // GDR, most likely no qualification
replace schooldegree=3 if ID_t==8020255 & splink==220002 // FRG, most likely MR (precondition for subsequent spell)
replace schooltype=.a if ID_t==8020255 & splink==220002  // same case, correct school type (implausible) to unknown 
replace schooldegree=.y if ID_t==8020638 & splink==220001 // GDR, most likely no qualification
replace schooldegree=3 if ID_t==8021185 & splink==220001 // GDR, most likely MR (precondition for subsequent spell)
replace schooldegree=.y if ID_t==8021325 & splink==220001 // GDR, most likely no qualification
replace schooldegree=.y if ID_t==8021383 & splink==220002 // FRG, most likely no qualification
replace schooltype=.a if ID_t==8021383 & splink==220002   // same case, correct school type (implausible) to unknown
replace schooldegree=.y if ID_t==8021768 & splink==220001 // GDR, most likely no qualification
replace schooldegree=3 if ID_t==8022004 & splink==220002 // FRG, most likely MR (precondition for subsequent spell)
replace schooltype=.a if ID_t==8022004 & splink==220002  // same case, correct school type (implausible) to unknown 
replace schooldegree=.y if ID_t==8022434 & splink==220001 // GDR, most likely no qualification
replace schooldegree=.y if ID_t==8022447 & splink==220001 // GDR, most likely no qualification
replace schooldegree=3 if ID_t==8024077 & splink==220002 // GDR, most likely MR (misclassified of person did not pass exam)
replace schooltype=.a if ID_t==8024900 & splink==220002  // correct school type (implausible) to unknown 
* update: Grund-/Volksschule with unknown degree
drop temp1*
gen temp1a=1 if schooltype==1 & schooldegree==.a
bys ID_t: egen temp1b=max(temp1a)
tab temp1b if n==1 // 23 cases

*** Grund-/Volksschule with multiple Spells
* replace school leaving degree if subsequent spell in Volks-/Hauptschule states "no qual. intended" --> recode to .x "no qual. intended"
sort ID_t month
gen temp2a= 1 if schooltype==1 & schooltype[_n+1]==1 & schooldegree!=.x & schooldegree[_n+1]==.x & ID_t==ID_t[_n+1] 
bys ID_t (month): egen temp2b=max(temp2a)
//list ID_t splink schooltype schooldegree startagey endagey schoolgpa month dur agey end temp2b fedschool temp2a if temp2b==1, sepby(ID_t)
bys ID_t splink: egen temp2c=max(temp2a) 
replace schooldegree=.x if temp2c==1
drop temp1* temp2*
sort ID_t month


*** HAUPT-, REAL-, SEKUNDAR-, REGEL-, MITTELSCHULE *****************************

*** Implausible school-leaving degrees
gen temp1a=1 if schooltype==2 & inlist(schooldegree,4,5) // FH-Reife, Abitur
bys ID_t: egen temp1b=max(temp1a)
tab temp1b if n==1 // --> 94 observations
//list ID_t splink schooltype schooldegree startagey endagey schoolgpa month dur agey end fedschool if temp1b==1, sepby(ID_t) // --> leave as is for now!!!
gen temp2a=1 if schooltype==2 & schooldegree==6 // special needs school degree
bys ID_t: egen temp2b=max(temp2a)
tab temp2b if n==1 // --> 2 observations
//list ID_t splink schooltype schooldegree startagey endagey schoolgpa month dur agey end fedschool if temp2b==1, sepby(ID_t) // --> leave as is
drop temp1* temp2* 


*** GYMNASIUM ******************************************************************

*** Implausible school-leaving degrees
gen temp1a=1 if schooltype==5 & inlist(schooldegree,1,2,6) // Hauptschulabschluss, qual. HSA, special needs school degree
bys ID_t: egen temp1b=max(temp1a)
tab temp1b if n==1 // --> 34 observations
// list ID_t splink schooltype schooldegree startagey endagey schoolgpa month dur agey end fedschool if temp1b==1, sepby(ID_t)
replace schooldegree=.y if ID_t==8001507 & splink==220002 // implausible, change to no degree 
replace schooltype=.a if ID_t==8002788 & splink==220001 // implausible, change to indeterminate school type
replace schooltype=.a if ID_t==8004830 & splink==220001 // implausible, change to indeterminate school type
drop temp1*


*** FURTHER INCONSISTENCIES ****************************************************

*** School-leaving degree has been obtained at age which is too young to make sense --> recode to .x "no qual. intended"
cap drop temp_dur temp_durcum
bys ID_t splink (month): egen temp_durcum=max(n) // cumulative duration in school at end of spell/date
replace schooldegree=.x if inrange(schooldegree,1,6) & endagey<12 & temp_durcum<90 // if younger than 12 years and cumulative duration less than 90 months

*** Same degree obtained twice or lower-level degree obtained after higher-level degree
* recode schooldegree variable into auxiliary variable with clear hierarchy 
lab def temp_sd /// 
        -6 "none (not in GER)" ///
		-5 "none" ///        
		-4 "Special needs (not in GER)" ///
		-3 "Special needs" ///
		-2 "unknown (not in GER)" ///
		-1 "unknown" ///
		1 "Haupt (not in GER)" ///
		2 "Haupt" ///
		3 "qual. Haupt (not in GER)" ///
		4 "qual. Haupt" ///
		5 "Mittl. Reife (not in GER)" ///
        6 "Mittl. Reife" ///
		7 "FH-Reife (not in GER)" ///
		8 "FH-Reife" ///		
		9 "Abitur (not in GER)" ///
		10 "Abitur" 
recode schooldegree (7 .a=-1) (6=-3) (.w .x .y=-5) (1=2) (2=4) (3=6) (4=8) (5=10), into(temp_sd) 
replace temp_sd=temp_sd-1 if gerschool==2 
lab val temp_sd temp_sd 
* generate cumulative variable indicating highest school degree at given month
sort ID_t month   
gen temp_sdcum=temp_sd
replace temp_sdcum=temp_sdcum[_n-1] if (temp_sdcum<=temp_sdcum[_n-1]) & ID_t==ID_t[_n-1]
lab val temp_sdcum temp_sd 
//list ID_t month temp_sd temp_sdcum, sepby(ID_t)  
* check and correct cases when lower-level degrees have been obtained after higher-level degree
gen temp1a=1 if temp_sd<temp_sdcum & inrange(temp_sd,1,10)
bys ID_t: egen temp1b=max(temp1a)
tab temp1b if n==1 // 40 cases
//list ID_t splink schooltype schooldegree temp_sdcum startagey endagey schoolgpa month dur agey end fedschool recog migration_age if temp1b==1, sepby(ID_t) 
// (edits only for most obvious cases, cases that are unclear are left as they are)
replace schooldegree=.a if ID_t==8000744 & splink==220002 // FH-Reife not plausible at that age, most likely Hauptschulabschluss or no degree
replace schoolgpa=.a if ID_t==8000744 & splink==220002    // GPA appears to belong to spell 220004 where FH-Reife has been obtained
replace schooldegree=.a if ID_t==8002673 & splink==220002 // Abitur not plausible at type of school and age, most likely no degree, Abitur in spell 220004
replace schooldegree=.a if ID_t==8007767 & splink==220002 // Abitur not plausible at type of school and age, most likely no degree
replace schoolgpa=.a if ID_t==8007767 & splink==220002    // 
replace schooldegree=.a if ID_t==8009900 & splink==220002 // Mittlere Reife not plausible at that age, most likely no degree
replace schoolgpa=.a if ID_t==8009900 & splink==220002    //
replace schooldegree=.a if ID_t==8011173 & splink==220003 // FH-Reife not plausible at that age, no other information would suggest it, most likely no degree
replace schooldegree=.y if ID_t==8024822 & splink==220003 // Abitur not plausible at that age and with subsequent career, very likely no degree
replace schoolgpa=.a if ID_t==8024822 & splink==220003    //
  
*** Set GPA to missing if no schooldegree has been obtained 
replace schoolgpa=.m if inlist(schooldegree,.w,.x,.y)
lab def schoolgpa .m "no grade", modify

*** Save data ******************************************************************
drop temp* monthnr
compress
save "${savedta}\school_plausi.dta", replace	
exit

