********************************************************************************
* Recode vocational training basics                                            *
*                                                                              *    
* Steffen Schindler, 15/05/2025                                                *
********************************************************************************

clear
set more off
cap log close

version 16.1

use "${savedta}\month_episodes", clear
keep if sptype==24 // keep only vocational training spells

*** merge information on year of birth and immigration history 
merge m:1 ID_t using "${savedta}\basicinfo.dta", nogen keep(1 3) keepusing(birthdate migration_age)
*generate age in months and in years
gen agem=month-birthdate
lab var agem "age in months"
gen agey=(month-birthdate)/12
lab var agey "age in years"

*** merge information from voctrain dataset 
gen subspell = 0   
merge m:1 ID_t splink subspell using "${savedta}\SC6_spVocTrain_D_${SUF}.dta", ///
nogen keep(1 3) keepusing(ts15201 ts15201_v1 ts15218 ts15218_v1 ts15206_g1 ts15207_g2 ts15265 ts15219_ha ts1512c_g1)
sort ID_t month monthnr

*** recodes 

* type of vocational training
fre ts15201 ts15201_v1
gen voctype=ts15201 
recode voctype (1=1) (2 3=2) (4=3) (5=4) (6/7=5) (8=6) (9=7) (10=8) (11=9) (12=10) (13=11) (14=12) (15=14) (16=15) (17=16) (.b .c .l=.a) (.m=.m)
lab var voctype "type of vocational training" 
lab def voctype ///
1 "vt apprenticeship" ///
2 "vt Berufsfachschule" ///
3 "vt Fachschule" ///
4 "master craftsman/techn." ///
5 "univ.coop.educ (BA/VWA)" ///
6 "college publ.admin (VFH)" ///
7 "univ.appl.sciences (FH)" ///
8 "university" ///
9 "medical special.train" ///
10 "course civil service exam" ///
11 "course at assoc./chamber (IHK)" ///
12 "course for lisense" ///
13 "other course" ///
14 "doctorate" ///
15 "habilitation" ///
16 "other voc.train" ///
.a "indeterminate" ///
.m "missing by design"
lab val voctype voctype 
ta ts15201 voctype,m
replace voctype=1 if voctype>=. & ts15201_v1==1
replace voctype=2 if voctype>=. & ts15201_v1==2
replace voctype=3 if voctype>=. & ts15201_v1==3
replace voctype=4 if voctype>=. & ts15201_v1==4
replace voctype=5 if voctype>=. & ts15201_v1==5
replace voctype=7 if voctype>=. & ts15201_v1==6
replace voctype=8 if voctype>=. & ts15201_v1==7
replace voctype=14 if voctype>=. & ts15201_v1==8
replace voctype=15 if voctype>=. & ts15201_v1==9
replace voctype=9 if voctype>=. & ts15201_v1==10
replace voctype=10 if voctype>=. & ts15201_v1==11
replace voctype=11 if voctype>=. & ts15201_v1==12
replace voctype=12 if voctype>=. & ts15201_v1==13
replace voctype=13 if voctype>=. & ts15201_v1==14
fre voctype 

* ongoing episode (ts1512c_g1)
rename ts1512c_g1 voctraincont
fre voctraincont

* vocational training degree (ts15219_ha)
rename ts15219_ha vocdegree_detail // detailed version
recode vocdegree_detail (. .b .c .e .l=.a) (.y=.y) 
replace vocdegree_detail=.y if ts15218==2 // ts15219_ha contains non-completed degrees --> set to .y
replace vocdegree_detail=.w if vocdegree_detail>=. & voctraincont==1
lab var vocdegree_detail "vocational training degree (detail)"
lab copy en1963ext1 vocdegree_detail
lab val vocdegree_detail vocdegree_detail
lab def vocdegree_detail .a"indeterminate" .b" " .c" " .e" " .l" " .w"still attending this training" .y"no qualification", modify
fre vocdegree_detail
gen vocdegree=vocdegree_detail // crude version
replace vocdegree=1 if vocdegree_detail==1 // Gesellen- oder Gehilfenbrief
replace vocdegree=1 if vocdegree_detail==2 // Berufsfachschulabschluss oder Abschluss Schule im Gesundheitswesen
replace vocdegree=2 if vocdegree_detail==3 // Fachschulabschluss
replace vocdegree=2 if vocdegree_detail==4 // Meisterbrief
replace vocdegree=2 if vocdegree_detail==5 // Technikerabschluss
replace vocdegree=2 if vocdegree_detail==6 // Abschluss an Berufs-, Verwaltungs-, Wirtschaftsakademie oder Verwaltungsfachhochschule
replace vocdegree=3 if vocdegree_detail==7 // Fachhochschulabschluss
replace vocdegree=3 if vocdegree_detail==8 // Universitätsabschluss
replace vocdegree=4 if vocdegree_detail==9 // Facharzt
replace vocdegree=4 if vocdegree_detail==10 // Promotion
replace vocdegree=4 if vocdegree_detail==11 // Habilitation
replace vocdegree=1 if vocdegree_detail==12 // Laufbahnprüfung einfacher Dienst
replace vocdegree=1 if vocdegree_detail==13 // Laufbahnprüfung mittlerer Dienst
replace vocdegree=2 if vocdegree_detail==14 // Laufbahnprüfung gehobener Dienst
replace vocdegree=2 if vocdegree_detail==15 // Laufbahnprüfung höherer Dienst
replace vocdegree=1 if vocdegree_detail==16 // IHK-Prüfung
replace vocdegree=5 if vocdegree_detail==17 // sonstiger Abschluss
lab def vocdegree ///
		1 "VOC1 lower-level vocational training" ///
		2 "VOC2 higher-level vocational training" ///
		3 "HE1 higher education" ///
        4 "HE2 post-higher education" ///  	
        5 "other qualification" ///
		.a "indeterminate" ///
		.w "still attending training" ///
		.y "no qualification"
lab val vocdegree vocdegree
fre vocdegree

* grade point average of vocational training degree (ts15265) 
rename ts15265 vocgpa
recode vocgpa (. .b .c=.a) (.m=.m) (.x=.x)  
replace vocgpa=.w if vocgpa>=. & voctraincont==1
lab var vocgpa "GPA vocational training degree"
lab copy enext4 vocgpa
lab def vocgpa .a"indeterminate" .b" " .c" " .m"missing by design" .w"still attending this training", modify
lab val vocgpa vocgpa
fre vocgpa

* vocational training attended in Germany (ts15206_g1)
rename ts15206_g1 gertrain
recode gertrain (. .b .c=.a) 
replace gertrain=1 if gertrain==.x // count as GER if GER and another country
lab var gertrain "vocational training attended in Germany"
lab copy en262ext2 gertrain
lab def gertrain .a "indeterminate" .b" " .c" " .x" " .y" ", modify
lab val gertrain gertrain
bys ID_t splink: egen temp=min(agey)
replace gertrain=2 if gertrain==.a & temp<migration_age & migration_age<. // replace if immigration later than training attendance 
drop temp
sort ID_t month
fre gertrain

* federal state (ts15207_g2)
rename ts15207_g2 fedtrain
replace fedtrain=.x if gertrain==2
replace fedtrain=20 if gertrain==1 & !inrange(fedtrain,1,16)
recode fedtrain (. .b .c .l .m=.a)  
lab var fedtrain "federal state of vocational training"
lab copy en1619ext1 fedtrain
lab def fedtrain 20"Germany (not further specified)" .a"indeterminate" .l" " .x"abroad", modify
lab val fedtrain fedtrain 
fre fedtrain 

*** save dataset
sort ID_t month monthnr
save "${savedta}\voctrain_basics", replace
exit 



