********************************************************************************
* VocTrain basics plausibility checks and corrections                          *
*                                                                              *    
* Steffen Schindler, 15/06/2025                                                *
********************************************************************************

clear
set more off
cap log close

version 16.1

use "${savedta}\voctrain_basics.dta"

*** PREPARATION ****************************************************************

* create new indicator of parallel month spells (only vocational training spells)
bys ID_t month (splink vocdegree): gen monthnr_voc=_n 
* sort date and create spell number
bys ID_t (month monthnr_voc): gen n=_n
* create indicators for start and end of spell/date
bys ID_t splink: egen start=min(month)
lab var start "start of spell (months since 01/1960)"
bys ID_t splink: egen end=max(month)
lab var end "end of spell (months since 01/1960)"


*** PARALLEL VOCATIONAL TRAINING SPELLS ****************************************

* inspect and delete duplicates (incl. federal state) 
duplicates tag ID_t sptype voctype vocdegree month fedtrain, gen(temp1a)
ta temp1a,m 
bys ID_t: egen temp1b=max(temp1a)
ta temp1b if n==1 
gen temp_mo=month
sort ID_t month monthnr_voc
//list ID_t splink voctype vocdegree month temp_mo monthnr_voc dur agey vocgpa fedtrain temp1a if temp1b>0, sepby(ID_t)
bysort ID_t month temp1a (dur splink): gen temp2=_n if temp1a>0 // generate rank order of spell duration (and splink) among duplicates 
//list ID_t splink voctype vocdegree month temp_mo monthnr_voc dur temp2 agey vocgpa fedtrain temp1a if temp1b>0, sepby(ID_t)
drop if temp2<=temp1a // drop duplicates with the shortes duration (with lowest splink numbers if duration is identical)
drop temp1* temp2

* inspect and delete remaining duplicates (excl. federal state) 
duplicates tag ID_t sptype voctype vocdegree month, gen(temp1a) // excl. federal state
ta temp1a,m 
bys ID_t: egen temp1b=max(temp1a)
ta temp1b if n==1 
sort ID_t month monthnr_voc
bysort ID_t month temp1a (dur splink): gen temp2=_n if temp1a>0 // generate rank order of spell duration (and splink) among duplicates 
//list ID_t splink voctype vocdegree month temp_mo monthnr_voc dur temp2 agey vocgpa fedtrain temp1a if temp1b>0, sepby(ID_t)
//no indication of unrealistic parallel spells --> no interference  
drop temp1* temp2

* update indicator of parallel month spells 
drop monthnr_voc
bys ID_t month (splink): gen monthnr_voc=_n 

* inspect parallel spells
bys ID_t: egen temp1=max(monthnr_voc)
ta temp1 if n==1 // 1,380 cases with 2 parallel spells, 42 cases with 3 parallel spells, 4 cases with 4 prallel spells
//list ID_t splink voctype vocdegree month temp_mo monthnr_voc dur agey vocgpa fedtrain temp1 if temp1>2, sepby(ID_t) // >2 parallel spells
//no indication of unrealistic parallel spells --> no interference


*** Save data ******************************************************************
drop temp* subspell ts15201_v1 ts15201 ts15218_v1 ts15218
compress
save "${savedta}\voctrain_plausi.dta", replace	
exit

