********************************************************************************
* Information on participation in waves                              		   *
*      							                                               *    
* Steffen Schindler, 15/06/2025                               				   *
********************************************************************************

clear
set more off
cap log close

version 16.1

use ID_t wave tx80220 tx8600m tx8600y using "${savedta}\SC6_CohortProfile_D_${SUF}.dta"


* recode wave number of last participation
gen temp=wave if tx80220==1
bys ID_t: egen partlast=max(temp)
lab copy en1871ext1 wave
lab var partlast "wave of last participation"
lab val partlast wave 
drop temp

* recode wave number of first participation
gen temp=wave if tx80220==1
bys ID_t: egen partfirst=min(temp)
lab var partfirst "wave of first participation"
lab val partfirst wave 
drop temp

* binary indicator of participation
recode tx80220 (1=1 "yes") (else=0 "no"), into(part_w)
lab var part_w "participation in wave"

* recode number of participations
bys ID_t: egen partnum=total(part_w)
lab var partnum "number of waves participating"

* date of interviews
gen date_w = ym(tx8600y,tx8600m)
format date_w %tm

* date of last interview
bys ID_t: egen lastint=max(date_w)
format lastint %tm
lab var lastint "date of last interview (months since Jan 1960)"

* reshape into wide format
drop tx80220 tx8600m tx8600y
reshape wide part_w date_w, i(ID_t) j(wave)
foreach num of numlist 1/14{
   replace part_w`num'=0 if part_w`num'==.  
   lab var part_w`num' "participation in wave`num'"
   lab var date_w`num' "date of interview wave`num' (months since Jan 1960)"
   }
order ID_t part_* date_* partfirst partlast partnum lastint

*** save data ******************************************************************
compress
save "${savedta}\wavepart.dta", replace

   